@@ -100,7 +100,6 @@ typedef struct {
   CHAR *inputfile;                  /**< input frame file name pattern */
   CHAR *channel;                    /**< the frame channel to read */
   CHAR *outputfile;                 /**< name of output file */
-  BOOLEAN version;	            /**< output version-info */
 } UserInput_t;
 
 /***********************************************************************************************/
@@ -232,8 +231,6 @@ int main( int argc, char *argv[] )
 void ReadUserVars(LALStatus *status,int argc,char *argv[],UserInput_t *uvar)
 {
   
-  CHAR *version_string;
-
   INITSTATUS(status);
   ATTATCHSTATUSPTR (status);
 
@@ -246,24 +243,12 @@ void ReadUserVars(LALStatus *status,int argc,char *argv[],UserInput_t *uvar)
   LALregSTRINGUserStruct(status,inputfile, 	'i', UVAR_REQUIRED, "The input frame name pattern"); 
   LALregSTRINGUserStruct(status,outputfile, 	'o', UVAR_REQUIRED, "The output statistics file"); 
   LALregSTRINGUserStruct(status,channel, 	'c', UVAR_REQUIRED, "The frame channel to be read"); 
-  LALregBOOLUserStruct(status,	version,        'V', UVAR_SPECIAL,  "Output code version");
 
   /* do ALL cmdline and cfgfile handling */
   BOOLEAN should_exit = 0;
   LAL_CALL (LALUserVarReadAllInput(status->statusPtr, &should_exit, argc, argv), status->statusPtr);
   if (should_exit) exit(1);
 
-  if ((version_string = XLALGetVersionString(0)) == NULL) {
-    XLALPrintError("XLALGetVersionString(0) failed.\n");
-    exit(1);
-  }
-  
-  if (uvar->version) {
-    printf("%s\n",version_string);
-    exit(0);
-  }
-  XLALFree(version_string);
-
   DETATCHSTATUSPTR (status);
   RETURN (status);
 
