@@ -956,6 +956,7 @@ int main( int argc, char *argv[] )
   }
 
   /* write the sim_inspiral table */
+  XLALSimInspiralAssignIDs ( inspInjections.simInspiralTable, 0, 0 );
   if ( inspInjections.simInspiralTable )
   {
     LAL_CALL( LALBeginLIGOLwXMLTable( &status, &xmlfp, sim_inspiral_table ), 
@@ -964,12 +965,11 @@ int main( int argc, char *argv[] )
           sim_inspiral_table ), &status );
     LAL_CALL( LALEndLIGOLwXMLTable ( &status, &xmlfp ), &status );
   }
-
   while ( inspInjections.simInspiralTable )
   {
     inj = inspInjections.simInspiralTable;
     inspInjections.simInspiralTable = inspInjections.simInspiralTable->next;
-    LALFree( inj );
+    XLALFreeSimInspiral( &inj );
   }
 
    
