@@ -1,5 +1,6 @@
 ##############################################################################
 # import standard modules
+import itertools
 import os, sys, re, copy
 from optparse import OptionParser
 import tempfile
@@ -8,7 +9,6 @@ import tempfile
 # import the modules we need to build the pipeline
 from glue import pipeline
 from glue import lal
-from glue import iterutils
 from glue.ligolw import ligolw
 from glue.ligolw import lsctables
 from glue.ligolw import utils
@@ -712,7 +712,7 @@ for result_db in result_dbs_cache:
   distinct_instrument_sets = [instruments]
   distinct_instrument_sets.extend( set(sub_combo)
     for nn in range(2, len(instruments))
-    for sub_combo in iterutils.choices( list(instruments), nn ) )
+    for sub_combo in itertools.combinations( list(instruments), nn ) )
 
   # add the injection xmls to the FULL_DATA databases
   if 'FULL_DATA' in tag and veto_cat in sim_caches:
