@@ -39,6 +39,7 @@
 #include <lal/LALStdlib.h>
 #include <lal/LALError.h>
 #include <lal/LALDatatypes.h>
+#include <lal/LIGOMetadataInspiralUtils.h>
 #include <lal/LIGOMetadataTables.h>
 #include <lal/LIGOMetadataUtils.h>
 #include <lal/AVFactories.h>
@@ -200,7 +201,7 @@ int main(INT4 argc, CHAR *argv[])
 
   /* read all command line variables */
   BOOLEAN should_exit = 0;
-  XLAL_CHECK_MAIN(XLALUserVarReadAllInput(&should_exit, argc, argv) == XLAL_SUCCESS, XLAL_EFUNC);
+  XLAL_CHECK_MAIN(XLALUserVarReadAllInput(&should_exit, argc, argv, lalAppsVCSInfoList) == XLAL_SUCCESS, XLAL_EFUNC);
   if (should_exit)
     exit(1);
 
@@ -352,6 +353,7 @@ int main(INT4 argc, CHAR *argv[])
 
 
   /* and finally the simInspiralTable itself */
+  XLALSimInspiralAssignIDs(injections.simInspiralTable, 0, 0);
   if (injections.simInspiralTable)
   {
     LAL_CALL(LALBeginLIGOLwXMLTable(&status, &xmlfp, sim_inspiral_table),
@@ -373,7 +375,7 @@ int main(INT4 argc, CHAR *argv[])
   {
     this_inj = injections.simInspiralTable;
     injections.simInspiralTable = injections.simInspiralTable->next;
-    LALFree(this_inj);
+    XLALFreeSimInspiral(&this_inj);
   }
 
 #if 0
