@@ -64,6 +64,10 @@ def get_universe(config_parser):
 	return config_parser.get("condor", "universe")
 
 
+def get_accounting_group(config_parser):
+	return config_parser.get("condor", "accounting_group")
+
+
 def get_executable(config_parser, name):
 	return config_parser.get("condor", name)
 
@@ -153,7 +157,12 @@ def make_cache_entry(input_cache, description, path):
 	if path:
 		url = "file://localhost%s" % os.path.abspath(path)
 	else:
-		url = None
+		# FIXME:  old version of CacheEntry allowed None for URL,
+		# new version doesn't.  correct fix is to modify calling
+		# code to not try to initialize the output cache until
+		# after the input is known, but for now we'll just do this
+		# stupid hack.
+		url = "file://localhost/dev/null"
 
 	# construct a cache entry from the instruments and
 	# segments that remain
@@ -229,6 +238,7 @@ class RMJob(pipeline.CondorDAGJob):
 		self.set_stdout_file(os.path.join(get_out_dir(config_parser), "rm-$(cluster)-$(process).out"))
 		self.set_stderr_file(os.path.join(get_out_dir(config_parser), "rm-$(cluster)-$(process).err"))
 		self.add_condor_cmd("getenv", "True")
+		self.add_condor_cmd("accounting_group", get_accounting_group(config_parser))
 		self.add_opt("force", "")
 		self.set_sub_file("rm.sub")
 
@@ -274,6 +284,7 @@ class BurstInjJob(pipeline.CondorDAGJob, pipeline.AnalysisJob):
 		self.set_stdout_file(os.path.join(get_out_dir(config_parser), "lalapps_binj-$(macrogpsstarttime)-$(macrogpsendtime)-$(cluster)-$(process).out"))
 		self.set_stderr_file(os.path.join(get_out_dir(config_parser), "lalapps_binj-$(macrogpsstarttime)-$(macrogpsendtime)-$(cluster)-$(process).err"))
 		self.add_condor_cmd("getenv", "True")
+		self.add_condor_cmd("accounting_group", get_accounting_group(config_parser))
 		self.set_sub_file("lalapps_binj.sub")
 
 		self.output_dir = "."
@@ -282,7 +293,7 @@ class BurstInjJob(pipeline.CondorDAGJob, pipeline.AnalysisJob):
 		self.time_step = config_parser.getfloat("lalapps_binj", "time-step")
 
 
-class BurstInjNode(pipeline.AnalysisNode):
+class BurstInjNode(pipeline.CondorDAGNode,pipeline.AnalysisNode):
 	def __init__(self, job):
 		pipeline.CondorDAGNode.__init__(self, job)
 		pipeline.AnalysisNode.__init__(self)
@@ -364,6 +375,7 @@ class PowerJob(pipeline.CondorDAGJob, pipeline.AnalysisJob):
 		self.set_stdout_file(os.path.join(get_out_dir(config_parser), "lalapps_power-$(cluster)-$(process).out"))
 		self.set_stderr_file(os.path.join(get_out_dir(config_parser), "lalapps_power-$(cluster)-$(process).err"))
 		self.add_condor_cmd("getenv", "True")
+		self.add_condor_cmd("accounting_group", get_accounting_group(config_parser))
 		self.set_sub_file("lalapps_power.sub")
 
 		self.output_dir = "."
@@ -502,6 +514,7 @@ class BucutJob(pipeline.CondorDAGJob):
 		self.set_stdout_file(os.path.join(get_out_dir(config_parser), "lalapps_bucut-$(cluster)-$(process).out"))
 		self.set_stderr_file(os.path.join(get_out_dir(config_parser), "lalapps_bucut-$(cluster)-$(process).err"))
 		self.add_condor_cmd("getenv", "True")
+		self.add_condor_cmd("accounting_group", get_accounting_group(config_parser))
 		self.add_condor_cmd("Requirements", "Memory > 1100")
 		self.add_ini_opts(config_parser, "lalapps_bucut")
 
@@ -547,6 +560,7 @@ class BuclusterJob(pipeline.CondorDAGJob):
 		self.set_stdout_file(os.path.join(get_out_dir(config_parser), "lalapps_bucluster-$(cluster)-$(process).out"))
 		self.set_stderr_file(os.path.join(get_out_dir(config_parser), "lalapps_bucluster-$(cluster)-$(process).err"))
 		self.add_condor_cmd("getenv", "True")
+		self.add_condor_cmd("accounting_group", get_accounting_group(config_parser))
 		self.add_condor_cmd("Requirements", "Memory > 1100")
 		self.add_ini_opts(config_parser, "lalapps_bucluster")
 
@@ -602,6 +616,7 @@ class BinjfindJob(pipeline.CondorDAGJob):
 		self.set_stdout_file(os.path.join(get_out_dir(config_parser), "lalapps_binjfind-$(cluster)-$(process).out"))
 		self.set_stderr_file(os.path.join(get_out_dir(config_parser), "lalapps_binjfind-$(cluster)-$(process).err"))
 		self.add_condor_cmd("getenv", "True")
+		self.add_condor_cmd("accounting_group", get_accounting_group(config_parser))
 		self.add_ini_opts(config_parser, "lalapps_binjfind")
 
 		self.files_per_binjfind = get_files_per_binjfind(config_parser)
@@ -646,6 +661,7 @@ class BurcaJob(pipeline.CondorDAGJob):
 		self.set_stdout_file(os.path.join(get_out_dir(config_parser), "lalapps_burca-$(cluster)-$(process).out"))
 		self.set_stderr_file(os.path.join(get_out_dir(config_parser), "lalapps_burca-$(cluster)-$(process).err"))
 		self.add_condor_cmd("getenv", "True")
+		self.add_condor_cmd("accounting_group", get_accounting_group(config_parser))
 		self.add_condor_cmd("Requirements", "Memory >= $(macrominram)")
 		self.add_ini_opts(config_parser, "lalapps_burca")
 
@@ -661,6 +677,7 @@ class Burca2Job(pipeline.CondorDAGJob):
 		self.set_stdout_file(os.path.join(get_out_dir(config_parser), "lalapps_burca2-$(cluster)-$(process).out"))
 		self.set_stderr_file(os.path.join(get_out_dir(config_parser), "lalapps_burca2-$(cluster)-$(process).err"))
 		self.add_condor_cmd("getenv", "True")
+		self.add_condor_cmd("accounting_group", get_accounting_group(config_parser))
 		self.add_ini_opts(config_parser, "lalapps_burca2")
 
 		self.cache_dir = get_cache_dir(config_parser)
@@ -716,6 +733,7 @@ class SQLiteJob(pipeline.CondorDAGJob):
 		self.set_stdout_file(os.path.join(get_out_dir(config_parser), "ligolw_sqlite-$(cluster)-$(process).out"))
 		self.set_stderr_file(os.path.join(get_out_dir(config_parser), "ligolw_sqlite-$(cluster)-$(process).err"))
 		self.add_condor_cmd("getenv", "True")
+		self.add_condor_cmd("accounting_group", get_accounting_group(config_parser))
 		self.add_ini_opts(config_parser, "ligolw_sqlite")
 
 
@@ -765,6 +783,7 @@ class BurcaTailorJob(pipeline.CondorDAGJob):
 		self.set_stdout_file(os.path.join(get_out_dir(config_parser), "lalapps_burca_tailor-$(cluster)-$(process).out"))
 		self.set_stderr_file(os.path.join(get_out_dir(config_parser), "lalapps_burca_tailor-$(cluster)-$(process).err"))
 		self.add_condor_cmd("getenv", "True")
+		self.add_condor_cmd("accounting_group", get_accounting_group(config_parser))
 		self.add_ini_opts(config_parser, "lalapps_burca_tailor")
 
 		self.cache_dir = get_cache_dir(config_parser)
@@ -1050,7 +1069,7 @@ def make_lladd_fragment(dag, parents, tag, segment = None, input_cache = None, r
 	[cache_entry] = node.get_output_cache()
 	if segment is None:
 		segment = cache_entry.segment
-	node.set_name("lladd_%s_%s_%d_%d" % (tag, cache_entry.observatory, int(segment[0]), int(abs(segment))))
+	node.set_name("lladd_%s_%d_%d" % (tag, int(segment[0]), int(abs(segment))))
 	node.set_output(os.path.join(node.output_dir, "%s-%s-%d-%d.xml.gz" % (cache_entry.observatory, tag, int(segment[0]), int(abs(segment)))), segment = segment)
 
 	node.set_retry(3)
@@ -1095,7 +1114,7 @@ def make_binj_fragment(dag, seg, time_slides_cache_entry, tag, offset, flow = No
 		node.add_macro("macroflow", flow)
 	if fhigh is not None:
 		node.add_macro("macrofhigh", fhigh)
-	node.add_macro("macroseed", int(time.time() + start))
+	node.add_macro("macroseed", int(time.time()%100 + start))
 	dag.add_node(node)
 	return set([node])
 
@@ -1393,7 +1412,8 @@ def group_coinc_parents(parents, offset_vectors, extentlimit = None, verbose = F
 	# returns the bins sorted by segment, so we do too
 	#
 
-	caches = [set(bin.objects) for bin in bins]
+	caches = [frozenset(bin.objects) for bin in bins]
+	assert len(set(caches)) == len(caches)
 	segs = [cache_span(bin.objects) for bin in bins]
 
 	#
@@ -1412,7 +1432,7 @@ def group_coinc_parents(parents, offset_vectors, extentlimit = None, verbose = F
 				lo = segments.NegInfinity
 			else:
 				lo = extent[0]
-			if i >= len(extents) - 2 or extents[i + 1].disjoint(extent):
+			if i >= len(extents) - 1 or extents[i + 1].disjoint(extent):
 				hi = segments.PosInfinity
 			else:
 				hi = extent[1]
