@@ -925,6 +925,9 @@ void get_input_args(inputParams_t *inputParams, INT4 argc, CHAR *argv[]){
         else
           fprintf(stderr, "Error passing option %s with argument %s\n",
             long_options[option_index].name, LALoptarg);
+#if __GNUC__ >= 7
+        __attribute__ ((fallthrough));
+#endif
       case 'h': /* help message */
         fprintf(stderr, USAGE, program);
         exit(0);
@@ -981,7 +984,6 @@ void get_input_args(inputParams_t *inputParams, INT4 argc, CHAR *argv[]){
         inputParams->nyears = atoi(LALoptarg);
         break;
       case '?':
-        fprintf(stderr, "Unknown error while parsing options\n");
       default:
         fprintf(stderr, "Unknown error while parsing options\n");
     }
