@@ -43,7 +43,6 @@
 
 
 /* user input variables */
-BOOLEAN  uvar_version;     /**< output version information */
 BOOLEAN  uvar_averagePsi;
 BOOLEAN  uvar_averageIota;
 BOOLEAN  uvar_autoCorrelate;
@@ -205,8 +204,6 @@ int main(int argc, char *argv[]){
   static SFTConstraints constraints;
   INT4 sftcounter = 0, slidingcounter = 1, listLength = 0;
 
-  CHAR *VCSInfoString;          /**< LAL + LALapps Git version string */
-
   /* to time the code*/
   time_t t1, t2;
 
@@ -218,21 +215,10 @@ int main(int argc, char *argv[]){
 
   /* read all command line variables */
   BOOLEAN should_exit = 0;
-  XLAL_CHECK_MAIN( XLALUserVarReadAllInput(&should_exit, argc, argv) == XLAL_SUCCESS, XLAL_EFUNC);
+  XLAL_CHECK_MAIN( XLALUserVarReadAllInput(&should_exit, argc, argv, lalAppsVCSInfoList) == XLAL_SUCCESS, XLAL_EFUNC);
   if (should_exit)
     exit(1);
 
-
-  if ( (VCSInfoString = XLALGetVersionString(0)) == NULL ) {
-    XLALPrintError("XLALGetVersionString(0) failed.\n");
-    exit(1);
-  }
-
-  if ( uvar_version ) {
-    printf ("%s\n", VCSInfoString );
-    exit (0);
-  }
-
   /* very basic consistency checks on user input */
   if ( uvar_f0 < 0 ) {
     fprintf(stderr, "start frequency must be positive\n");
@@ -1066,9 +1052,6 @@ printf("%g %g\n", sigmasq->data[i] * ualpha->data[i].re, sigmasq->data[i] * ualp
   XLALDestroyREAL8Vector(galphare);
   XLALDestroyREAL8Vector(galphaim);
 
-  if ( VCSInfoString )
-    XLALFree ( VCSInfoString );
-
   if (!uvar_averagePsi) {
     LALFree(psi);
   }
@@ -1715,7 +1698,6 @@ void initUserVars (LALStatus *status)
 
   uvar_maxlag = 0;
 
-  uvar_version = FALSE;
   uvar_averagePsi = TRUE;
   uvar_averageIota = TRUE;
   uvar_autoCorrelate = FALSE;
@@ -1767,7 +1749,6 @@ void initUserVars (LALStatus *status)
   strcpy(uvar_skyfile,SKYFILE);
 
   /* register user input variables */
-  XLAL_CHECK_LAL( status, XLALRegisterNamedUvar( &uvar_version,                "version",       BOOLEAN, 'V', SPECIAL,  "Output version information") == XLAL_SUCCESS, XLAL_EFUNC );
   XLAL_CHECK_LAL( status, XLALRegisterNamedUvar( &uvar_averagePsi,             "averagePsi",    BOOLEAN, 0,   OPTIONAL, "Use average over psi") == XLAL_SUCCESS, XLAL_EFUNC );
   XLAL_CHECK_LAL( status, XLALRegisterNamedUvar( &uvar_averageIota,            "averageIota",   BOOLEAN, 0,   OPTIONAL, "Use average over iota") == XLAL_SUCCESS, XLAL_EFUNC );
   XLAL_CHECK_LAL( status, XLALRegisterNamedUvar( &uvar_autoCorrelate,          "autoCorrelate", BOOLEAN, 0,   OPTIONAL, "Include autocorrelations") == XLAL_SUCCESS, XLAL_EFUNC );
