@@ -28,7 +28,12 @@
 #include <stdlib.h>
 
 #if defined(HAVE_LIBCFITSIO)
+// disable -Wstrict-prototypes flag for this header file as this causes
+// a build failure for cfitsio-3.440+
+#pragma GCC diagnostic ignored "-Wstrict-prototypes"
 #include <fitsio.h>
+#pragma GCC diagnostic pop
+
 #else
 #error CFITSIO library is not available
 #endif
@@ -40,7 +45,7 @@ int main(int argc, char *argv[])
   int hdutype = 0, bitpix = 0, bytepix = 0, naxis = 0, nkeys = 0, datatype = 0, anynul = 0;
   long naxes[9] = {1, 1, 1, 1, 1, 1, 1, 1, 1};
   long first = 0, totpix = 0, npix = 0;
-  double *array = 0, bscale = 1.0, bzero = 0.0, nulval = 0.;
+  double *array = 0, bscale = 1.0, b0 = 0.0, nulval = 0.;
   char card[81];
 
   int printhelp = (argc == 2 && (strcmp(argv[1], "-h") == 0 || strcmp(argv[1], "--help") == 0));
@@ -189,8 +194,8 @@ int main(int argc, char *argv[])
       }
 
       /* turn off any scaling so that we copy the raw pixel values */
-      fits_set_bscale(infptr,  bscale, bzero, &status);
-      fits_set_bscale(outfptr, bscale, bzero, &status);
+      fits_set_bscale(infptr,  bscale, b0, &status);
+      fits_set_bscale(outfptr, bscale, b0, &status);
 
       first = 1;
       while (totpix > 0 && !status) {
