@@ -68,7 +68,8 @@ int main(int argc, char **argv)
     LIGOTimeGPS startTime, endTime; 
     REAL8 avg =0;
     REAL4 *timeavg =NULL;
-    REAL4 PWR,SNR;
+    /*REAL4 PWR,SNR;*/ /* 06/15/2017 gam; No longer compute SNR in this code.  */ 
+    REAL4 PWR;
     REAL8 f =0;
     CHAR outbase[256],outfile[256],outfile2[256],outfile3[256], outfile4[256]; /*, outfile6[256]; */
     REAL8 NumBinsAvg =0;
@@ -87,7 +88,7 @@ int main(int argc, char **argv)
     
     /* these varibales are for converting GPS seconds into UTC time and date*/
     struct tm         date;
-    CHARVector        *timestamp = NULL;
+    /*CHARVector        *timestamp = NULL; */ /* 06/15/2017 gam; not used  */
     CHARVector	     *year_date = NULL;
     REAL8Vector     *timestamps=NULL;
     
@@ -114,7 +115,7 @@ int main(int argc, char **argv)
     XLAL_CHECK_MAIN( XLALRegisterNamedUvar(&sunFile,      "sunFile",      STRING, 'z', OPTIONAL, "sun .dat file" ) == XLAL_SUCCESS, XLAL_EFUNC);
     
     BOOLEAN should_exit = 0;
-    XLAL_CHECK_MAIN(XLALUserVarReadAllInput(&should_exit, argc, argv) == XLAL_SUCCESS, XLAL_EFUNC);
+    XLAL_CHECK_MAIN(XLALUserVarReadAllInput(&should_exit, argc, argv, lalAppsVCSInfoList) == XLAL_SUCCESS, XLAL_EFUNC);
     if (should_exit)
       return(1);
     
@@ -160,7 +161,8 @@ int main(int argc, char **argv)
     sprintf(outbase, "spec_%.2f_%.2f_%s_%d_%d", f_min,f_max,constraints.detector,startTime.gpsSeconds,endTime.gpsSeconds);/*cg; this is the default name for producing the output files, the different suffixes are just added to this*/
     sprintf(outfile,  "%s", outbase);/*cg; name of first file to be output*/
     sprintf(outfile2, "%s_timestamps", outbase);/*cg: name of second file to be output*/
-    sprintf(outfile3, "%s.txt", outbase);/*cg; name of third file to be output*/
+    /* sprintf(outfile3, "%s.txt", outbase); */ /*cg; name of third file to be output*/
+    sprintf(outfile3, "%s_timeaverage", outbase); /* Use the old outfile3 name from this code; python code will output the .txt version of this file. */
     sprintf(outfile4, "%s_date", outbase);/*cg;file for outputting the date, which is used in matlab plotting.*/
 
     fp = fopen(outfile, "w");/*cg;  open all three files for writing, if they don't exist create them, if they do exist overwrite them*/
@@ -195,9 +197,9 @@ int main(int argc, char **argv)
             avg = 0.0;/*cg; the vairable avg is reset each time.*/
             if (i+NumBinsAvg>numBins) {printf("Error\n");return(2);}/*cg; error is detected, to prevent referencing data past the end of sft_vect.*/
             for (k=0;k<NumBinsAvg;k++)/*cg; for each bin, k goes trhough each entry from 0 to 180.*/
-                avg += sqrt(2*(crealf(sft_vect->data[j].data->data[i+k])*crealf(sft_vect->data[j].data->data[i+k]) + 
-                cimagf(sft_vect->data[j].data->data[i+k])*cimagf(sft_vect->data[j].data->data[i+k]))/timebaseline);/*cg; re amd im are real and imaginary parts of SFT, duh!*/
-            fprintf(fp,"%e\t",avg/NumBinsAvg);
+                avg += 2.0*(crealf(sft_vect->data[j].data->data[i+k])*crealf(sft_vect->data[j].data->data[i+k]) +
+                cimagf(sft_vect->data[j].data->data[i+k])*cimagf(sft_vect->data[j].data->data[i+k]))/timebaseline;/* 06/15/2017 gam; avg power */
+            fprintf(fp,"%e\t",sqrt(avg/NumBinsAvg)); /* 06/15/2017 gam; then take sqrt here. */
         }
         fprintf(fp,"\n");
         /*------------------------------*/
@@ -259,8 +261,9 @@ int main(int argc, char **argv)
     {
         f = sft_vect->data->f0 + ((REAL4)i)*sft_vect->data->deltaF;
 	PWR=timeavg[i]/((REAL4)nSFT);
-	SNR=(PWR-1)*(sqrt(((REAL4)nSFT)));
-        fprintf(fp3,"%16.8f %g %g\n",f, PWR, SNR);
+	/* SNR=(PWR-1)*(sqrt(((REAL4)nSFT))); */ /* 06/15/2017 gam; no longer compute SNR in this code */
+        /*fprintf(fp3,"%16.8f %g %g\n",f, PWR, SNR); */ /* 06/15/2017 gam; Let's not include SNR and print with fewer decimal places */
+        fprintf(fp3,"%16.6f %16.3f \n",f, PWR); 
     } 
 /*------------------------------------------------------------------------------------------------------------------------*/ 
 /*End of normal spec_avg code, the remaining code is for crab freq calc.*/
@@ -274,7 +277,7 @@ int main(int argc, char **argv)
     /*some header files for the crab*/
     /*#include "../TDS_isolated/HeterodyneCrabPulsar.h"*/
     /*#include "../TDS_isolated/heterodyne_pulsar.h"*/
-    #include<../TDS_isolated/HeterodyneCrabPulsar.h>
+    #include<../HeterodyneSearch/HeterodyneCrabPulsar.h>
 
     if (psrInput != NULL){
 
@@ -348,7 +351,7 @@ int main(int argc, char **argv)
     /* read in tempo par file for pulsar, This is one of the optional command line arguments*/
     /*fprintf(stderr,"%s\n",psrInput);*/
     fprintf(stderr,"%s\n",psrInput);
-    XLALReadTEMPOParFile(&pulsarParams, psrInput);
+    XLALReadTEMPOParFileOrig(&pulsarParams, psrInput);
 
     /*Make sure that posepoch and pepoch are set*/
     if(pulsarParams.pepoch == 0. && pulsarParams.posepoch != 0.)
@@ -488,7 +491,7 @@ int main(int argc, char **argv)
 
 
     /*release a;; the allocaeted memory*/
-    LALCHARDestroyVector(&status, &timestamp);
+    /*LALCHARDestroyVector(&status, &timestamp); */ /* 06/15/2017 gam; not used */ 
     LALCHARDestroyVector(&status, &year_date);
     XLALDestroySFTVector ( sft_vect );
 
