@@ -140,7 +140,7 @@ int main(int argc,char *argv[])
 
   /* read cmdline & cfgfile  */	
   BOOLEAN should_exit = 0;
-  XLAL_CHECK_MAIN (XLALUserVarReadAllInput(&should_exit, argc, argv) == XLAL_SUCCESS, XLAL_EFUNC);
+  XLAL_CHECK_MAIN (XLALUserVarReadAllInput(&should_exit, argc, argv, lalAppsVCSInfoList) == XLAL_SUCCESS, XLAL_EFUNC);
   if (should_exit)
     return EXIT_FAILURE;
   LAL_CALL ( CheckUserInput (&status, &CommandLineArgs), &status);
