@@ -126,7 +126,6 @@ typedef struct {
   CHAR *ephemEarth;	/**< Earth ephemeris file to use */
   CHAR *ephemSun;	/**< Sun ephemeris file to use */
 
-  BOOLEAN version;	/**< output version-info */
   INT4 randSeed;	/**< GSL random-number generator seed value to use */
 } UserInput_t;
 
@@ -187,25 +186,13 @@ int main(int argc,char *argv[])
 
   /* do ALL cmdline and cfgfile handling */
   BOOLEAN should_exit = 0;
-  if ( XLALUserVarReadAllInput ( &should_exit, argc, argv ) != XLAL_SUCCESS ) {
+  if ( XLALUserVarReadAllInput ( &should_exit, argc, argv, lalAppsVCSInfoList ) != XLAL_SUCCESS ) {
     LogPrintf ( LOG_CRITICAL, "%s: XLALUserVarReadAllInput() failed with errno=%d\n", __func__, xlalErrno );
     return 1;
   }
   if ( should_exit )
     return EXIT_FAILURE;
 
-  if ( uvar.version ) {
-    /* output verbose VCS version string if requested */
-    CHAR *vcs;
-    if ( (vcs = XLALGetVersionString (lalDebugLevel)) == NULL ) {
-      LogPrintf ( LOG_CRITICAL, "%s:XLALGetVersionString(%d) failed with errno=%d.\n", __func__, lalDebugLevel, xlalErrno );
-      return 1;
-    }
-    printf ( "%s\n", vcs );
-    XLALFree ( vcs );
-    return 0;
-  }
-
   /* ---------- Initialize code-setup ---------- */
   if ( XLALInitCode( &cfg, &uvar ) != XLAL_SUCCESS ) {
     LogPrintf (LOG_CRITICAL, "%s: XLALInitCode() failed with error = %d\n", __func__, xlalErrno );
@@ -213,16 +200,16 @@ int main(int argc,char *argv[])
   }
 
   /* ----- prepare stats output ----- */
-  FILE *fpTransientStats = NULL;
+  LALFILE *fpTransientStats = NULL;
   if ( uvar.outputStats )
     {
-      if ( (fpTransientStats = fopen (uvar.outputStats, "wb")) == NULL)
+      if ( (fpTransientStats = XLALFileOpen (uvar.outputStats, "wb")) == NULL)
 	{
 	  LogPrintf (LOG_CRITICAL, "Error opening file '%s' for writing..\n\n", uvar.outputStats );
 	  XLAL_ERROR ( XLAL_EIO );
 	}
-      fprintf (fpTransientStats, "%s", cfg.logString );		/* write search log comment */
-      if ( write_transientCandidate_to_fp ( fpTransientStats, NULL ) != XLAL_SUCCESS ) { /* write header-line comment */
+      XLALFilePrintf (fpTransientStats, "%s", cfg.logString );		/* write search log comment */
+      if ( write_transientCandidate_to_fp ( fpTransientStats, NULL, 'd' ) != XLAL_SUCCESS ) { /* write header-line comment */
         XLAL_ERROR ( XLAL_EFUNC );
       }
     } /* if outputStats */
@@ -356,7 +343,7 @@ int main(int argc,char *argv[])
       if ( uvar.outputAtoms )
         {
 
-          FILE *fpAtoms;
+          LALFILE *fpAtoms;
           char *fnameAtoms;
           UINT4 len = strlen ( uvar.outputAtoms ) + 20;
           if ( (fnameAtoms = XLALCalloc ( 1, len )) == NULL ) {
@@ -365,11 +352,11 @@ int main(int argc,char *argv[])
           }
           sprintf ( fnameAtoms, "%s_%04d_of_%04d.dat", uvar.outputAtoms, i + 1, uvar.numDraws );
 
-          if ( ( fpAtoms = fopen ( fnameAtoms, "wb" )) == NULL ) {
+          if ( ( fpAtoms = XLALFileOpen ( fnameAtoms, "wb" )) == NULL ) {
             XLALPrintError ("%s: failed to open atoms-output file '%s' for writing.\n", __func__, fnameAtoms );
             XLAL_ERROR ( XLAL_EFUNC );
           }
-	  fprintf ( fpAtoms, "%s", cfg.logString );	/* output header info */
+	  XLALFilePrintf ( fpAtoms, "%s", cfg.logString );	/* output header info */
 
 	  if ( write_MultiFstatAtoms_to_fp ( fpAtoms, multiAtoms ) != XLAL_SUCCESS ) {
             XLALPrintError ("%s: failed to write atoms to output file '%s'. xlalErrno = %d\n", __func__, fnameAtoms, xlalErrno );
@@ -377,7 +364,7 @@ int main(int argc,char *argv[])
           }
 
           XLALFree ( fnameAtoms );
-	  fclose (fpAtoms);
+	  XLALFileClose (fpAtoms);
         } /* if outputAtoms */
 
       /* ----- if requested, output Fstat-map over {t0, tau} */
@@ -445,7 +432,7 @@ int main(int argc,char *argv[])
 
 
       /* ----- if requested, output transient-cand statistics */
-      if ( fpTransientStats && write_transientCandidate_to_fp ( fpTransientStats, &cand ) != XLAL_SUCCESS ) {
+      if ( fpTransientStats && write_transientCandidate_to_fp ( fpTransientStats, &cand, 'd' ) != XLAL_SUCCESS ) {
         XLALPrintError ( "%s: write_transientCandidate_to_fp() failed.\n", __func__ );
         XLAL_ERROR ( XLAL_EFUNC );
       }
@@ -459,7 +446,7 @@ int main(int argc,char *argv[])
     } /* for i < numDraws */
 
   /* ----- close files ----- */
-  if ( fpTransientStats) fclose ( fpTransientStats );
+  XLALFileClose ( fpTransientStats );
   if ( fpInjParams ) fclose ( fpInjParams );
 
   /* ----- free memory ---------- */
@@ -601,8 +588,6 @@ XLALInitUserVars ( UserInput_t *uvar )
   XLALRegisterUvarMember( ephemEarth, 	 STRING, 0,  OPTIONAL, "Earth ephemeris file to use");
   XLALRegisterUvarMember( ephemSun, 	 	 STRING, 0,  OPTIONAL, "Sun ephemeris file to use");
 
-  XLALRegisterUvarMember( version,        	BOOLEAN, 'V', SPECIAL,  "Output code version");
-
   /* 'hidden' stuff */
   XLALRegisterUvarMember( TAtom,		  	  INT4, 0, DEVELOPER, "Time baseline for Fstat-atoms (typically Tsft) in seconds." );
 
