@@ -75,7 +75,9 @@
 
 /* for finding out and logging the glibc version */
 #ifdef __GLIBC__
+#ifndef _GNU_SOURCE
 #define _GNU_SOURCE
+#endif
 #include <gnu/libc-version.h>
 #endif
 
@@ -726,7 +728,7 @@ static int resolve_and_unzip(const char*filename, /**< filename to resolve */
     /* boinc_resove() returned the same filename, so filename wasn't a softlink */
 
     strncpy(buf,filename,sizeof(buf));
-    strncat(buf,LINKED_EXT,sizeof(buf));
+    strncat(buf,LINKED_EXT,sizeof(buf)-1-strlen(buf));
     /* f**king BOINC's new symlink behavior returns no error if the link file doesn't,
        exist, so we need to check it manually */
     if((fp=fopen(buf,"r"))) {
@@ -1143,8 +1145,8 @@ static int worker (void) {
       second_outfile = -1;
     }
 
-    /* record if there will be a second output file */
-    else if (!strcmp("--SortToplist=6",argv[arg])) {
+    /* record if there will be triple output files */
+    else if (!strcmp("--SortToplist=6",argv[arg]) || !strcmp("--SortToplist=7",argv[arg])) {
       rargv[rarg] = argv[arg];
       LogPrintf(LOG_DEBUG,"BSGL output files\n");
       bsgl_outfiles = -1;
@@ -1329,10 +1331,38 @@ static int worker (void) {
   if(test_sqrt)
     fprintf(stderr,"NaN:%f\n", sqrt(-1));
 
-  if(!bundle_size && (fp = boinc_fopen(resultfile,"r"))) {
-    fclose(fp);
-    LogPrintf (LOG_NORMAL, "WARNING: Resultfile '%s' present - doing nothing\n", resultfile);
-    resultfile_present = 1;
+  if(!bundle_size) {
+    int curresultfile, nresultfiles = 1;
+    char*lastchar = &resultfile[strlen(resultfile)-1];
+    char*filenums = "0123";
+
+    if (*lastchar == '0') { // boinc_resove()d result name
+
+      resultfile_present = 1; // assume all are present until we know better
+
+      if (second_outfile)
+        nresultfiles = 2;
+      else if (bsgl_outfiles)
+        nresultfiles = 3;
+
+      for (curresultfile = 0; curresultfile < nresultfiles; curresultfile++) {
+        *lastchar = filenums[curresultfile];
+        if (!boinc_file_exists(resultfile)) {
+          resultfile_present = 0;
+          break;
+        }
+      }
+      *lastchar = '0';
+      if(resultfile_present) {
+        LogPrintf (LOG_NORMAL, "WARNING: Resultfile '%s' present - doing nothing\n", resultfile);
+      }
+
+    } else if (boinc_file_exists(resultfile)) {
+
+      resultfile_present = 1;
+      LogPrintf (LOG_NORMAL, "WARNING: Resultfile '%s' present - doing nothing\n", resultfile);
+
+    }
   }
 
 #ifdef BOINC_APIV6
@@ -1376,7 +1406,7 @@ static int worker (void) {
 	  n = current_config_file;
 	strcpy(&wu_result_file[rlen-1], myltoa(n, buf, 20));
 	*config_file_arg = config_files[current_config_file];
-	if (fp = boinc_fopen(wu_result_file,"r")) {
+	if ((fp = boinc_fopen(wu_result_file,"r"))) {
 	  fclose(fp);
 	  LogPrintf (LOG_NORMAL, "WARNING: Resultfile '%s' present - skipping subWU#%d\n", wu_result_file, current_config_file);
 	  current_config_file ++;
@@ -1406,6 +1436,31 @@ static int worker (void) {
 #endif
       }
 
+#define APP_WISDOM_FILENAME "CW-wisdom.dat"
+      /* if there is a wisdom file, point environment variable FFTWF_WISDOM_FILENAME to it */
+      {
+        static char resolved_name[MAX_PATH_LEN];
+        strncpy(resolved_name, "FFTWF_WISDOM_FILENAME=", MAX_PATH_LEN);
+        char*path = resolved_name+strlen(resolved_name);
+
+        strncat(resolved_name, eah_projectdir, MAX_PATH_LEN-strlen(resolved_name)-1);
+#ifdef _WIN32
+#define PATH_DELIM "\\"
+#else
+#define PATH_DELIM "/"
+#endif
+        strncat(resolved_name, PATH_DELIM APP_WISDOM_FILENAME, MAX_PATH_LEN-strlen(resolved_name));
+        if (boinc_file_exists(path)) {
+          putenv(resolved_name);
+          fprintf(stderr, "INFO: Set %s\n", resolved_name);
+
+        } else if (boinc_file_exists(APP_WISDOM_FILENAME)) {
+          boinc_resolve_filename(APP_WISDOM_FILENAME, path, MAX_PATH_LEN-strlen(resolved_name)-1);
+          putenv(resolved_name);
+          fprintf(stderr, "INFO: Set %s\n", resolved_name);
+        }
+      }
+
       /* CALL WORKER's MAIN()
        */
       res = MAIN(rargc,rrargv);
@@ -1539,6 +1594,8 @@ int main(int argc, char**argv) {
                          BOINC_DIAG_REDIRECTSTDERR |
                          BOINC_DIAG_TRACETOSTDERR);
 
+  LogSetFile(stderr); /* send all LogPrint output to stderr */
+
   LogPrintf(LOG_NORMAL, "This program is published under the GNU General Public License, version 2\n");
   LogPrintf(LOG_NORMAL, "For details see http://einstein.phys.uwm.edu/license.php\n");
   LogPrintf(LOG_NORMAL, "This Einstein@home App was built at: " __DATE__ " " __TIME__ "\n");
@@ -1583,8 +1640,10 @@ int main(int argc, char**argv) {
     } /* if DEBUG_LEVEL_FNAME file found */
 
   {
-    char buf[8];
-    if (setenv("LAL_DEBUG_LEVEL", myultoa(eah_lal_debug_level, buf, 8), 1)) {
+    char buf[16+8];
+    strcpy(buf, "LAL_DEBUG_LEVEL=");
+    myultoa(eah_lal_debug_level, buf+16, 8);
+    if (putenv(buf)) {
       LogPrintf(LOG_CRITICAL,"ERROR: couldn't set LAL_DEBUG_LEVEL env: %d\n", errno);
     }
   }
@@ -1666,6 +1725,7 @@ int main(int argc, char**argv) {
 
 
 
+
   /* install signal handler */
 
   /* the previous boinc_init_diagnostics() call should have installed boinc_catch_signal() for
@@ -1739,7 +1799,7 @@ int main(int argc, char**argv) {
   set_boinc_options();
   boinc_init();
   int ret = worker();
-  if ( (ret == HS_BOINC_EXIT_MEM) ) {
+  if (ret == HS_BOINC_EXIT_MEM) {
     DeferExecution(); // calls boinc_temporary_exit() and ends the program
   }
   else {
