@@ -156,7 +156,7 @@ FreqStep=`echo $mfd_FreqBand $numFreqBands |  awk '{print $1 / $2}'`
 mfd_fBand=`echo $FreqStep $Tsft |  awk '{print ($1 - 1.5 / $2)}'`	## reduce by 1/2 a bin to avoid including last freq-bins
 
 # construct common MFD cmd
-mfd_CL_common="--Band=${mfd_fBand} --injectionSources=\"{Freq=$Freq; f1dot=$f1dot; f2dot=$f2dot; Alpha=$Alpha; Delta=$Delta; psi=$psi; phi0=$phi0; h0=$h0; cosi=$cosi; refTime=$refTime}\" --Tsft=$Tsft --randSeed=1000 --outSingleSFT --IFOs=H1,L1 --timestampsFiles=${tsFile_H1},${tsFile_L1}"
+mfd_CL_common="--Band=${mfd_fBand} --Tsft=$Tsft --randSeed=1000 --outSingleSFT --IFOs=H1,L1 --timestampsFiles=${tsFile_H1},${tsFile_L1}"
 
 if [ "$sqrtSh" != "0" ]; then
     mfd_CL_common="$mfd_CL_common --sqrtSX=${sqrtSh},${sqrtSh}";
@@ -167,6 +167,9 @@ while [ $iFreq -le $numFreqBands ]; do
     mfd_fi=`echo $mfd_fmin $iFreq $FreqStep | awk '{print $1 + ($2 - 1) * $3}'`
 
     cmdline="$mfd_code $mfd_CL_common --fmin=$mfd_fi --outSFTdir=${SFTdir} --outLabel=freqBand$iFreq"
+    if [ $iFreq -eq 2 ]; then
+        cmdline="$cmdline --injectionSources=\"{Freq=$Freq; f1dot=$f1dot; f2dot=$f2dot; Alpha=$Alpha; Delta=$Delta; psi=$psi; phi0=$phi0; h0=$h0; cosi=$cosi; refTime=$refTime}\""
+    fi
     if [ -n "$DEBUG" ]; then
         cmdline="$cmdline"
     else
@@ -386,8 +389,8 @@ fi
 
 echo
 echo "----------------------------------------------------------------------------------------------------"
-echo " STEP 7: run HierarchSearchGCT using Resampling and triple toplist (BSGL, BSGLtL and BtSGLtL), "
-echo "         compared with separate runs for each of these 3 toplist rankings"
+echo " STEP 7: run HierarchSearchGCT using Resampling and triple toplists (BSGL, BSGLtL and BtSGLtL), "
+echo "          (2F, BSGLtL and BtSGLtL), compared with separate runs for each of these 3 toplist rankings"
 echo "----------------------------------------------------------------------------------------------------"
 echo
 
@@ -395,6 +398,8 @@ rm -f checkpoint.cpt # delete checkpoint to start correctly
 outfile_GCT_RS_triple="${testDir}/GCT_RS_triple.dat"
 timingsfile_RS_triple="${testDir}/timing_RS_triple.dat"
 
+outfile_GCT_RS_triple2="${testDir}/GCT_RS_triple2.dat"
+timingsfile_RS_triple2="${testDir}/timing_RS_triple2.dat"
 
 # set plan mode so that results should be deterministic, easier to compare results of different runs this way
 
@@ -416,7 +421,42 @@ if ! eval "$cmdline"; then
 fi
 
 
-## re-run, but now create the three toplists one by one, then compare results
+# second variant of triple toplists, with 2F sorted first toplist
+
+cmdline="$gct_code $gct_CL_common --FstatMethod=ResampGeneric --fnameout='$outfile_GCT_RS_triple2' --outputTiming='$timingsfile_RS_triple2' ${BSGL_flags} --getMaxFperSeg --loudestSegOutput --SortToplist=7"
+if [ -n "$DEBUG" ]; then
+    cmdline="$cmdline"
+else
+    cmdline="$cmdline &> /dev/null"
+fi
+
+echo $cmdline
+if ! eval "$cmdline"; then
+    echo "Error.. something failed when running '$gct_code' ..."
+    exit 1
+fi
+
+
+
+
+## re-run, but now create the in total four toplists one by one, then compare results
+
+outfile_GCT_RS_triple="${testDir}/GCT_RS_triple_0.dat"
+
+cmdline="$gct_code $gct_CL_common --FstatMethod=ResampGeneric --fnameout='$outfile_GCT_RS_triple' ${BSGL_flags} --getMaxFperSeg --loudestSegOutput --SortToplist=0"
+if [ -n "$DEBUG" ]; then
+    cmdline="$cmdline"
+else
+    cmdline="$cmdline &> /dev/null"
+fi
+
+echo $cmdline
+if ! eval "$cmdline"; then
+    echo "Error.. something failed when running '$gct_code' ..."
+    exit 1
+fi
+
+
 
 outfile_GCT_RS_triple="${testDir}/GCT_RS_triple_1.dat"
 
@@ -466,6 +506,7 @@ fi
 
 # filter out comments
 
+egrep -v "^%" ${testDir}/GCT_RS_triple_0.dat > ${testDir}/GCT_RS_triple_0.txt
 egrep -v "^%" ${testDir}/GCT_RS_triple_1.dat > ${testDir}/GCT_RS_triple_1.txt
 egrep -v "^%" ${testDir}/GCT_RS_triple_2.dat > ${testDir}/GCT_RS_triple_2.txt
 egrep -v "^%" ${testDir}/GCT_RS_triple_3.dat > ${testDir}/GCT_RS_triple_3.txt
@@ -475,6 +516,11 @@ egrep -v "^%" ${testDir}/GCT_RS_triple.dat > ${testDir}/GCT_RS_triple.txt
 egrep -v "^%" ${testDir}/GCT_RS_triple.dat-BSGLtL > ${testDir}/GCT_RS_triple-BSGLtL.txt
 egrep -v "^%" ${testDir}/GCT_RS_triple.dat-BtSGLtL > ${testDir}/GCT_RS_triple-BtSGLtL.txt
 
+egrep -v "^%" ${testDir}/GCT_RS_triple2.dat > ${testDir}/GCT_RS_triple2.txt
+egrep -v "^%" ${testDir}/GCT_RS_triple2.dat-BSGLtL > ${testDir}/GCT_RS_triple2-BSGLtL.txt
+egrep -v "^%" ${testDir}/GCT_RS_triple2.dat-BtSGLtL > ${testDir}/GCT_RS_triple2-BtSGLtL.txt
+
+
 if ! eval "diff ${testDir}/GCT_RS_triple_1.txt ${testDir}/GCT_RS_triple.txt"; then
     echo "Error: tripple toplists do not match separately generated toplists  (1) "
     exit 1
@@ -490,6 +536,24 @@ if ! eval "diff ${testDir}/GCT_RS_triple_3.txt ${testDir}/GCT_RS_triple-BtSGLtL.
     exit 1
 fi
 
+if ! eval "diff ${testDir}/GCT_RS_triple_0.txt ${testDir}/GCT_RS_triple2.txt"; then
+    echo "Error: tripple toplists do not match separately generated toplists  (4) "
+    exit 1
+fi
+
+if ! eval "diff ${testDir}/GCT_RS_triple_2.txt ${testDir}/GCT_RS_triple2-BSGLtL.txt"; then
+    echo "Error: tripple toplists do not match separately generated toplists  (5) "
+    exit 1
+fi
+
+if ! eval "diff ${testDir}/GCT_RS_triple_3.txt ${testDir}/GCT_RS_triple2-BtSGLtL.txt"; then
+    echo "Error: tripple toplists do not match separately generated toplists  (6) "
+    exit 1
+fi
+
+
+
+
 
 
 ## ---------- compute relative differences and check against tolerance --------------------
