@@ -83,7 +83,7 @@ int main(int argc, char *argv[]){
 
   CHAR outputfile[256]="";
   CHAR channel[128]="";
-  CHAR *psrname = NULL;
+  const CHAR *psrname;
 
   INT4Vector *starts=NULL, *stops=NULL; /* science segment start and stop times */
   INT4 numSegs=0;
@@ -105,18 +105,18 @@ int main(int argc, char *argv[]){
   hetParams.heterodyneflag = inputParams.heterodyneflag; /* set type of heterodyne */
 
   /* read in pulsar data */
-  hetParams.het = XLALReadTEMPOParFileNew( inputParams.paramfile );
+  hetParams.het = XLALReadTEMPOParFile( inputParams.paramfile );
   hetParams.hetUpdate = NULL;
 
   /* set pulsar name - take from par file if available, or if not get from command line args */
   if( PulsarCheckParam( hetParams.het, "PSRJ" ) )
-    psrname = XLALStringDuplicate( PulsarGetStringParam( hetParams.het, "PSRJ" ) );
+    psrname = PulsarGetStringParam( hetParams.het, "PSRJ" );
   else if( PulsarCheckParam( hetParams.het, "PSRB" ) )
-    psrname = XLALStringDuplicate( PulsarGetStringParam( hetParams.het, "PSRB" ) );
+    psrname = PulsarGetStringParam( hetParams.het, "PSRB" );
   else if( PulsarCheckParam( hetParams.het, "NAME" ) )
-    psrname = XLALStringDuplicate( PulsarGetStringParam( hetParams.het, "NAME" ) );
+    psrname = PulsarGetStringParam( hetParams.het, "NAME" );
   else if( PulsarCheckParam( hetParams.het, "PSR" ) )
-    psrname = XLALStringDuplicate( PulsarGetStringParam( hetParams.het, "PSR" ) );
+    psrname = PulsarGetStringParam( hetParams.het, "PSR" );
   else{
     fprintf(stderr, "No pulsar name specified!\n");
     exit(0);
@@ -143,7 +143,7 @@ int main(int argc, char *argv[]){
     fprintf(stderr, "alpha = %lf rads, delta = %lf rads.\n", rav, decv);
 
     if ( PulsarCheckParam( hetParams.het, "F" ) ) {
-      REAL8Vector *freqsv = PulsarGetREAL8VectorParam( hetParams.het, "F" );
+      const REAL8Vector *freqsv = PulsarGetREAL8VectorParam( hetParams.het, "F" );
       UINT4 i = 0;
 
       pepochv = PulsarGetREAL8ParamOrZero( hetParams.het, "PEPOCH" );
@@ -166,7 +166,7 @@ int main(int argc, char *argv[]){
   if(verbose){  fprintf(stderr, "I've set the detector location for %s.\n", inputParams.ifo); }
 
   if(inputParams.heterodyneflag == 2 || inputParams.heterodyneflag == 4){ /* if updating parameters read in updated par file */
-    hetParams.hetUpdate = XLALReadTEMPOParFileNew( inputParams.paramfileupdate );
+    hetParams.hetUpdate = XLALReadTEMPOParFile( inputParams.paramfileupdate );
 
     /* if there is an epoch given manually (i.e. not from the pulsar parameter
        file) then set it here and overwrite any other value */
@@ -188,7 +188,7 @@ int main(int argc, char *argv[]){
       fprintf(stderr, "alpha = %lf rads, delta = %lf rads.\n", rav, decv);
 
       if ( PulsarCheckParam( hetParams.hetUpdate, "F" ) ) {
-        REAL8Vector *freqsv = PulsarGetREAL8VectorParam( hetParams.hetUpdate, "F" );
+        const REAL8Vector *freqsv = PulsarGetREAL8VectorParam( hetParams.hetUpdate, "F" );
         UINT4 i = 0;
 
         pepochv = PulsarGetREAL8ParamOrZero( hetParams.hetUpdate, "PEPOCH" );
@@ -424,9 +424,9 @@ data!\n");
           starts->data[count] )
         break;
 
-      if((duration = stops->data[count] - starts->data[count]) > MAXDATALENGTH)
-        duration = MAXDATALENGTH; /* if duration of science segment is large
-                                     just get part of it */
+      if((duration = stops->data[count] - starts->data[count]) > inputParams.datachunklength)
+        duration = inputParams.datachunklength; /* if duration of science segment is large
+                                                   just get part of it */
 
       fprintf(stderr, "Getting data between %d and %d.\n", starts->data[count],
         starts->data[count]+duration);
@@ -437,7 +437,7 @@ data!\n");
 
       /* if there was no frame file for that segment move on */
       if((smalllist = set_frame_files(&starts->data[count], &stops->data[count],
-        cache, frcount, &count))==NULL){
+        cache, frcount, &count, inputParams.datachunklength))==NULL){
         /* if there was no frame file for that segment move on */
         fprintf(stderr, "Error... no frame files listed between %d and %d.\n",
           (INT4)gpstime, (INT4)gpstime + duration);
@@ -530,6 +530,9 @@ data!\n");
 
           if( XLALFileEOF(fpin) || rc == 0 ) break;
 
+          /* check that data is finite (and not unrealistically large) and not NaN */
+          if ( !isfinite(reVal) || !isfinite(imVal) || fabs(reVal) > 1. || fabs(imVal) > 1. ){ continue; }
+
           if(inputParams.scaleFac > 1.0){
             reVal *= inputParams.scaleFac;
             imVal *= inputParams.scaleFac;
@@ -570,6 +573,9 @@ data!\n");
             continue;
           }
 
+          /* check that data is finite (and not unrealistically large) and not NaN */
+          if ( !isfinite(reVal) || !isfinite(imVal) || fabs(reVal) > 1. || fabs(imVal) > 1. ){ continue; }
+
           if( inputParams.scaleFac > 1.0 ){
             reVal *= inputParams.scaleFac;
             imVal *= inputParams.scaleFac;
@@ -798,6 +804,7 @@ void get_input_args(InputParams *inputParams, int argc, char *argv[]){
     { "sample-rate",              required_argument,  0, 's' },
     { "resample-rate",            required_argument,  0, 'r' },
     { "data-file",                required_argument,  0, 'd' },
+    { "data-chunk-length",        required_argument,  0, 'D' },
     { "channel",                  required_argument,  0, 'c' },
     { "output-file",              required_argument,  0, 'o' },
     { "ephem-earth-file",         required_argument,  0, 'e' },
@@ -822,7 +829,7 @@ void get_input_args(InputParams *inputParams, int argc, char *argv[]){
     { 0, 0, 0, 0 }
   };
 
-  char args[] = "hi:p:z:f:g:k:s:r:d:c:o:e:S:t:l:R:C:F:O:T:m:G:H:M:ABbZLv";
+  char args[] = "hi:p:z:f:g:k:s:r:d:D:c:o:e:S:t:l:R:C:F:O:T:m:G:H:M:ABbZLv";
   char *program = argv[0];
 
   /* set defaults */
@@ -841,6 +848,7 @@ void get_input_args(InputParams *inputParams, int argc, char *argv[]){
   inputParams->calibfiles.sensingfunctionfile = NULL;
   inputParams->calibfiles.openloopgainfile = NULL;
   inputParams->calibfiles.responsefunctionfile = NULL;
+  inputParams->datachunklength = MAXDATALENGTH; /* default to MAXDATALENGTH */
 
   inputParams->freqfactor = 2.0; /* default is to look for gws at twice the
 pulsar spin frequency */
@@ -871,6 +879,7 @@ the pulsar parameter file */
         else
           fprintf(stderr, "Error parsing option %s with argument %s\n",
             long_options[option_index].name, LALoptarg );
+		break;
       case 'h': /* help message */
         fprintf(stderr, USAGE, program);
         exit(0);
@@ -967,6 +976,9 @@ the pulsar parameter file */
         snprintf(inputParams->datafile, sizeof(inputParams->datafile), "%s",
           LALoptarg);
         break;
+      case 'D': /* set the maximum data chunk length for reading in */ 
+        inputParams->datachunklength = atoi(LALoptarg);
+        break;
       case 'c': /* frame channel */
         snprintf(inputParams->channel, sizeof(inputParams->channel), "%s",
           LALoptarg);
@@ -1039,8 +1051,10 @@ the pulsar parameter file */
         break;
       case '?':
         fprintf(stderr, "unknown error while parsing options\n" );
+		break;
       default:
         fprintf(stderr, "unknown error while parsing options\n" );
+		break;
     }
   }
 
@@ -1065,6 +1079,11 @@ defined.\n");
     exit(0);
   }*/
 
+  if( inputParams->datachunklength <= 0 ){
+    fprintf(stderr, "Error... data chunk length must be greater than zero.\n");
+    exit(1);
+  }
+
   if(inputParams->freqfactor < 0.){
     fprintf(stderr, "Error... frequency factor must be greater than zero.\n");
     exit(1);
@@ -1179,8 +1198,8 @@ void heterodyne_data(COMPLEX16TimeSeries *data, REAL8Vector *times,
   REAL8 cgw = PulsarGetREAL8ParamOrZero( hetParams.het, "CGW" );
   REAL8 cgwu = PulsarGetREAL8ParamOrZero( hetParams.hetUpdate, "CGW" );
 
-  REAL8Vector *freqs = PulsarGetREAL8VectorParam( hetParams.het, "F" );
-  REAL8Vector *freqsu = NULL;
+  const REAL8Vector *freqs = PulsarGetREAL8VectorParam( hetParams.het, "F" );
+  const REAL8Vector *freqsu = NULL;
   if ( PulsarCheckParam( hetParams.hetUpdate, "F" ) ){
     freqsu = PulsarGetREAL8VectorParam( hetParams.hetUpdate, "F" );
   }
@@ -1189,53 +1208,52 @@ void heterodyne_data(COMPLEX16TimeSeries *data, REAL8Vector *times,
   REAL8 *glep = NULL, *glph = NULL, *glf0 = NULL, *glf1 = NULL, *glf2 = NULL, *glf0d = NULL, *gltd = NULL;
   UINT4 glnum = 0;
   if ( PulsarCheckParam( hetParams.hetUpdate, "GLEP" ) ){
-    REAL8Vector *glpars = NULL;
-    glpars = PulsarGetREAL8VectorParam( hetParams.hetUpdate, "GLEP" );
-    glnum = glpars->length;
+    const REAL8Vector *gleppars = PulsarGetREAL8VectorParam( hetParams.hetUpdate, "GLEP" );
+    glnum = gleppars->length;
 
     /* get epochs */
     glep = XLALCalloc(glnum, sizeof(REAL8)); /* initialise to zeros */
-    for ( i=0; i<(INT4)glpars->length; i++ ){ glep[i] = glpars->data[i]; }
+    for ( i=0; i<(INT4)gleppars->length; i++ ){ glep[i] = gleppars->data[i]; }
 
     /* get phase offsets */
     glph = XLALCalloc(glnum, sizeof(REAL8)); /* initialise to zeros */
     if ( PulsarCheckParam( hetParams.hetUpdate, "GLPH" ) ) {
-      glpars = PulsarGetREAL8VectorParam( hetParams.hetUpdate, "GLPH" );
+      const REAL8Vector *glpars = PulsarGetREAL8VectorParam( hetParams.hetUpdate, "GLPH" );
       for ( i=0; i<(INT4)glpars->length; i++ ){ glph[i] = glpars->data[i]; }
     }
 
     /* get frequencies offsets */
     glf0 = XLALCalloc(glnum, sizeof(REAL8)); /* initialise to zeros */
     if ( PulsarCheckParam( hetParams.hetUpdate, "GLF0" ) ) {
-      glpars = PulsarGetREAL8VectorParam( hetParams.hetUpdate, "GLF0" );
+      const REAL8Vector *glpars = PulsarGetREAL8VectorParam( hetParams.hetUpdate, "GLF0" );
       for ( i=0; i<(INT4)glpars->length; i++ ){ glf0[i] = glpars->data[i]; }
     }
 
     /* get frequency derivative offsets */
     glf1 = XLALCalloc(glnum, sizeof(REAL8)); /* initialise to zeros */
     if ( PulsarCheckParam( hetParams.hetUpdate, "GLF1" ) ) {
-      glpars = PulsarGetREAL8VectorParam( hetParams.hetUpdate, "GLF1" );
+      const REAL8Vector *glpars = PulsarGetREAL8VectorParam( hetParams.hetUpdate, "GLF1" );
       for ( i=0; i<(INT4)glpars->length; i++ ){ glf1[i] = glpars->data[i]; }
     }
 
     /* get second frequency derivative offsets */
     glf2 = XLALCalloc(glnum, sizeof(REAL8)); /* initialise to zeros */
     if ( PulsarCheckParam( hetParams.hetUpdate, "GLF2" ) ) {
-      glpars = PulsarGetREAL8VectorParam( hetParams.hetUpdate, "GLF2" );
+      const REAL8Vector *glpars = PulsarGetREAL8VectorParam( hetParams.hetUpdate, "GLF2" );
       for ( i=0; i<(INT4)glpars->length; i++ ){ glf2[i] = glpars->data[i]; }
     }
 
     /* get decaying frequency component offset derivative */
     glf0d = XLALCalloc(glnum, sizeof(REAL8)); /* initialise to zeros */
     if ( PulsarCheckParam( hetParams.hetUpdate, "GLF0D" ) ) {
-      glpars = PulsarGetREAL8VectorParam( hetParams.hetUpdate, "GLF0D" );
+      const REAL8Vector *glpars = PulsarGetREAL8VectorParam( hetParams.hetUpdate, "GLF0D" );
       for ( i=0; i<(INT4)glpars->length; i++ ){ glf0d[i] = glpars->data[i]; }
     }
 
     /* get decaying frequency component decay time constant */
     gltd = XLALCalloc(glnum, sizeof(REAL8)); /* initialise to zeros */
     if ( PulsarCheckParam( hetParams.hetUpdate, "GLTD" ) ) {
-      glpars = PulsarGetREAL8VectorParam( hetParams.hetUpdate, "GLTD" );
+      const REAL8Vector *glpars = PulsarGetREAL8VectorParam( hetParams.hetUpdate, "GLTD" );
       for ( i=0; i<(INT4)glpars->length; i++ ){ gltd[i] = glpars->data[i]; }
     }
   }
@@ -1303,8 +1321,8 @@ void heterodyne_data(COMPLEX16TimeSeries *data, REAL8Vector *times,
         REAL8 dtWave = (XLALGPSGetREAL8(&emit.te) - waveepoch)/86400.; /* in days */
         REAL8 tWave = 0.;
 
-        REAL8Vector *wavesin = PulsarGetREAL8VectorParam( hetParams.het, "WAVESIN" );
-        REAL8Vector *wavecos = PulsarGetREAL8VectorParam( hetParams.het, "WAVECOS" );
+        const REAL8Vector *wavesin = PulsarGetREAL8VectorParam( hetParams.het, "WAVESIN" );
+        const REAL8Vector *wavecos = PulsarGetREAL8VectorParam( hetParams.het, "WAVECOS" );
 
         for( UINT4 k = 0; k < wavesin->length; k++ ){
           tWave += wavesin->data[k]*sin(om*(REAL8)(k+1.)*dtWave) + wavecos->data[k]*cos(om*(REAL8)(k+1.)*dtWave);
@@ -1418,8 +1436,8 @@ void heterodyne_data(COMPLEX16TimeSeries *data, REAL8Vector *times,
       if ( PulsarCheckParam( hetParams.hetUpdate, "WAVESIN" ) && PulsarCheckParam( hetParams.hetUpdate, "WAVECOS" ) ){
         REAL8 dtWave = (XLALGPSGetREAL8(&emit.te) - waveepochu)/86400.; /* in days */
 
-        REAL8Vector *wavesin = PulsarGetREAL8VectorParam( hetParams.hetUpdate, "WAVESIN" );
-        REAL8Vector *wavecos = PulsarGetREAL8VectorParam( hetParams.hetUpdate, "WAVECOS" );
+        const REAL8Vector *wavesin = PulsarGetREAL8VectorParam( hetParams.hetUpdate, "WAVESIN" );
+        const REAL8Vector *wavecos = PulsarGetREAL8VectorParam( hetParams.hetUpdate, "WAVECOS" );
 
         for( UINT4 k = 0; k < wavesin->length; k++ ){
           tWave1 += wavesin->data[k]*sin(omu*(REAL8)(k+1.)*dtWave) + wavecos->data[k]*cos(omu*(REAL8)(k+1.)*dtWave);
@@ -1875,6 +1893,12 @@ INT4 heterodyneflag){
       linecount++;
   }
 
+  /* if segment list is empty exit with a warning */
+  if ( linecount == 0 ){
+    fprintf(stderr, "Warning... segment list file was empty, so no heterodyne will be performed\n");
+    exit(0);
+  }
+
   /* allocate memory for vectors */
   if( (starts = XLALResizeINT4Vector( starts, linecount )) == NULL ||
       (stops = XLALResizeINT4Vector( stops, linecount )) == NULL )
@@ -1927,7 +1951,7 @@ INT4 heterodyneflag){
 
 /* get frame data for partcular science segment */
 CHAR *set_frame_files(INT4 *starts, INT4 *stops, FrameCache cache,
-  INT4 numFrames, INT4 *position){
+  INT4 numFrames, INT4 *position, INT4 maxchunklength){
   INT4 i=0;
   INT4 durlock; /* duration of locked segment */
   INT4 tempstart, tempstop;
@@ -1942,8 +1966,8 @@ CHAR *set_frame_files(INT4 *starts, INT4 *stops, FrameCache cache,
   tempstop = *stops;
 
   /*if lock stretch is long can't read whole thing in at once so only do a bit*/
-  if( durlock > MAXDATALENGTH )
-    tempstop = tempstart + MAXDATALENGTH;
+  if( durlock > maxchunklength )
+    tempstop = tempstart + maxchunklength;
 
   for( i=0;i<numFrames;i++ ){
     if(tempstart >= cache.starttime[i]
@@ -1967,7 +1991,7 @@ XLALStringAppend!\n");
       break;
   }
 
-  if( durlock > MAXDATALENGTH ){/* set starts to its value plus MAXDATALENGTH*/
+  if( durlock > maxchunklength ){ /* set starts to its value plus maxchunklength */
     (*position)--; /* move position counter back one */
     *starts = tempstop;
   }
@@ -2238,6 +2262,8 @@ INT4 remove_outliers(COMPLEX16TimeSeries *data, REAL8Vector *times,
     }
   }
 
+  XLAL_CHECK( j > 0, XLAL_EFUNC, "Error... thresholding has rejected all the data!" );
+
   /* resize data and times */
   if( (data = XLALResizeCOMPLEX16TimeSeries(data, 0, j)) == NULL ||
       (times = XLALResizeREAL8Vector(times, j)) == NULL )
