@@ -45,8 +45,8 @@ matplotlib.use("Agg")
 
 from lalapps.pulsarpputils import *
 from lalapps.pulsarhtmlutils import *
-from pylal import bayespputils as bppu
-from pylal import git_version
+from lalinference.bayespputils import Posterior, PosteriorOneDPDF
+from lalinference import git_version
 
 __author__="Matthew Pitkin <matthew.pitkin@ligo.org>"
 __version__= "git id %s"%git_version.id
@@ -469,6 +469,10 @@ class posteriors:
       if hasattr(self._injection_parameters, 'DEC_RAD'):
         setattr(self._injection_parameters, 'DEC', self._injection_parameters['DEC_RAD'])
 
+      # if DIST is set, then use the original value in KPC as the posterior samples will be in KPC
+      if hasattr(self._injection_parameters, 'DIST'):
+        setattr(self._injection_parameters, 'DIST', self._injection_parameters['DIST_ORIGINAL'])
+
     if 'Joint' in self._ifos: # put 'Joint' at the end
       j = self._ifos.pop(self._ifos.index('Joint'))
       self._ifos.append(j)
@@ -501,13 +505,35 @@ class posteriors:
           if self._usegwphase and priorlinevals[0].lower() == 'phi0': # adjust phi0 priors if using GW phase
             ranges = 2.*ranges
         elif priorlinevals[1] is 'gmm':
-          nmodes = priorlinevals[2]
-          if len(priorlinevals) < 3 + nmodes*3:
-            print("Error... for 'gmm' prior there must be a mean, standard deviation and weight for each %d mode." % nmodes, file=sys.stderr)
-            sys.exit(1)
-          ranges = np.array([float(rv) for rv in priorlinevals[2:]])
-          if self._usegwphase and priorlinevals[0].lower() == 'phi0': # adjust phi0 priors if using GW phase
-            ranges = 2.*ranges[1:]
+          try:
+            ranges = {}
+            ranges['nmodes'] = priorlinevals[2]
+            ranges['means'] = ast.literal_eval(priorlinevals[3])   # means
+            ranges['covs'] = ast.literal_eval(priorlinevals[4])    # covariance matrices
+            ranges['weights'] = ast.literal_eval(priorlinevals[5]) # weights
+            plims = []
+            splitpars = [p.lower() for p in priorlinevals[0].split(':')] # split GMM parameter names
+            npars = len(splitpars)
+            for lims in priorlinevals[6:-1]: # limits for each parameter
+              plims.append(np.array(ast.literal_eval(lims)))
+            ranges['limits'] = plims
+            ranges['npars'] = npars
+            if self._usegwphase and 'phi0' in splitpars:
+              phi0idx = splitpars.index('phi0')
+              # adjust phi0 priors (multiply limits, means and covariances by 2.) if using GW phase
+              for ci in range(ranges['nmodes']):
+                ranges['means'][ci][phi0idx] = 2.*ranges['means'][ci][phi0idx]
+                for ck in range(npars): # this will correctly multiply the variances by 4 when ck == phi0idx
+                  ranges['covs'][ci][phi0idx][ck] = 2.*ranges['covs'][ci][phi0idx][ck]
+                  ranges['covs'][ci][ck][phi0idx] = 2.*ranges['covs'][ci][ck][phi0idx]
+              ranges['limits'][phi0idx] = 2.*ranges['limits'][phi0idx]
+            for sidx, spar in enumerate(splitpars):
+              ranges['pindex'] = sidx
+              self._prior_parameters[spar] = {'gmm': ranges}
+            continue
+          except:
+            # if can't read in GMM prior correctly then just continue
+            continue
 
         self._prior_parameters[priorlinevals[0]] = {priorlinevals[1]: ranges}
 
@@ -558,20 +584,20 @@ class posteriors:
               psisamples[i] = np.mod(psisamples[i], np.pi/2.)
               if phi0samples is not None: # rotate phi0 appropriately
                 phi0samples[i] += nrots*(np.pi/2.)
-            psisnew = bppu.PosteriorOneDPDF('psi', psisamples)
+            psisnew = PosteriorOneDPDF('psi', psisamples)
             pos.pop('psi')
             pos.append(psisnew)
 
           # make sure phi0 values are between 0->pi
           if phi0samples is not None:
             phi0samples = np.mod(phi0samples, np.pi)
-            phi0new = bppu.PosteriorOneDPDF('phi0', phi0samples)
+            phi0new = PosteriorOneDPDF('phi0', phi0samples)
             pos.pop('phi0')
             pos.append(phi0new)
 
         if self._usegwphase: # try switching phi0 to 2*phi0 if working with l=m=2 gravitational wave initial phase (e.g. for hardware injections)
           if 'phi0' in pos.names:
-            phi0new = bppu.PosteriorOneDPDF('phi0', 2.*pos['phi0'].samples)
+            phi0new = PosteriorOneDPDF('phi0', 2.*pos['phi0'].samples)
             pos.pop('phi0')
             pos.append(phi0new)
 
@@ -579,7 +605,7 @@ class posteriors:
         if len(self._harmonics) == 1:
           if self._harmonics[0] == 2.:
             if 'c22' in pos.names and self._modeltype == 'waveform':
-              h0new = bppu.PosteriorOneDPDF('h0', 2.*pos['c22'].samples)
+              h0new = PosteriorOneDPDF('h0', 2.*pos['c22'].samples)
               pos.pop('c22')
               pos.append(h0new)
               ih0 = self._parameters.index('h0')
@@ -590,7 +616,7 @@ class posteriors:
                   setattr(self._injection_parameters, 'H0', 2.*self._injection_parameters['C22'])
 
             if 'phi22' in pos.names and modeltype == 'waveform':
-              phi0new = bppu.PosteriorOneDPDF('phi0', 0.5*pos['phi22'].samples)
+              phi0new = PosteriorOneDPDF('phi0', 0.5*pos['phi22'].samples)
               pos.pop('phi0')
               pos.append(phi0new)
               iphi0 = self._parameters.index('phi0')
@@ -604,7 +630,7 @@ class posteriors:
         if len(self._harmonics) == 2:
           if 1. in self._harmonics and 2. in self._harmonics and self._biaxial and self._modeltype == 'waveform':
             if 'phi21' in pos.names:
-              phi22 = bppu.PosteriorOneDPDF('phi22', 2.*pos['phi21'].samples)
+              phi22 = PosteriorOneDPDF('phi22', 2.*pos['phi21'].samples)
               pos.append(phi22)
               if self._parfile is not None:
                 if hasattr(self._injection_parameters, 'PHI21'):
@@ -995,17 +1021,22 @@ class posteriors:
       vals[indices] = 1./(valrange[indices]*np.log(priorrange[1]/priorrange[0]))
     elif priortype == 'gmm':
       vals = np.zeros(len(valrange))
-      nmodes = priorrange[0]
-      mmeans = priorrange[1:(1+3*nmodes):3]
-      mstddevs = priorrange[2:(1+3*nmodes):3]
-      mweights = priorrange[3:(1+3*nmodes):3]
-      # check if bounds are given
+      nmodes = priorrange['nmodes'] # number of modes in GMM
+      pindex = priorrange['pindex'] # parameter index in GMM prior
+      mmeans = np.array([mm[pindex] for mm in priorrange['means']])  # means
+      mcovs = priorrange['covs']    # covariance matrices
+      mstddevs = []
+      for cov in mcovs:
+        mstddevs.append(np.sqrt(cov[pindex][pindex]))
+      mweights = priorrange['weights']
+      # check bounds
       bmin = -np.inf
       bmax = np.inf
-      if len(priorrange) > 1 + 3*nmodes: # there is a least a lower bound
-        bmin = priorrange[1+3*nmodes]
-        if len(priorrange) > 2 + 3*nmodes: # there is also an upper bound
-          bmax = priorrange[2+3*nmodes]
+      plims = priorrange['limits'][pindex]
+      if np.isfinite(plims[0]):
+        bmin = plims[0]
+      if np.isfinite(plims[1]):
+        bmax = plims[1]
       indices = (valrange >= bmin) & (valrange <= bmax)
 
       # crude (not taking account of wrap-around) shift of phi0 and psi into 0->pi and 0->pi/2 ranges)
@@ -1558,13 +1589,13 @@ class create_background(posteriors):
 
     # create fake posterior objects (requires logL to be there) for each detector
     for ifo in self._ifos:
-      self._posteriors[ifo] = bppu.Posterior((['tmp', 'logL'], np.zeros((100,2))))
+      self._posteriors[ifo] = Posterior((['tmp', 'logL'], np.zeros((100,2))))
 
       # add the SNR and Bsn values
-      snrs = bppu.PosteriorOneDPDF('snr', np.array([self._optimal_snrs[ifo]]).T)
+      snrs = PosteriorOneDPDF('snr', np.array([self._optimal_snrs[ifo]]).T)
       self._posteriors[ifo].append(snrs)
 
-      bsn = bppu.PosteriorOneDPDF('bsn', np.array([self._Bsn[ifo]]).T/np.log(10.)) # convert into base 10 log
+      bsn = PosteriorOneDPDF('bsn', np.array([self._Bsn[ifo]]).T/np.log(10.)) # convert into base 10 log
       self._posteriors[ifo].append(bsn)
 
       # remove temporary varaibles
@@ -1588,16 +1619,16 @@ class create_background(posteriors):
       if which != 'bci': # force which to be 'bci' (as there are only the two options)
         which = 'bci'
 
-    self._posteriors['Joint'] = bppu.Posterior((['tmp', 'logL'], np.zeros((100,2))))
+    self._posteriors['Joint'] = Posterior((['tmp', 'logL'], np.zeros((100,2))))
 
     # add the SNR and Bci values
-    snrs = bppu.PosteriorOneDPDF('snr', np.array([self._optimal_snrs['Joint']]).T)
+    snrs = PosteriorOneDPDF('snr', np.array([self._optimal_snrs['Joint']]).T)
     self._posteriors['Joint'].append(snrs)
 
     if which == 'bcin':
-      bci = bppu.PosteriorOneDPDF('bcin', np.array([self._Bcin]).T/np.log(10.))
+      bci = PosteriorOneDPDF('bcin', np.array([self._Bcin]).T/np.log(10.))
     else:
-      bci = bppu.PosteriorOneDPDF('bci', np.array([self._Bci]).T/np.log(10.))
+      bci = PosteriorOneDPDF('bci', np.array([self._Bci]).T/np.log(10.))
     self._posteriors['Joint'].append(bci)
 
     curifos = self._ifos # save current detectors
@@ -1832,7 +1863,7 @@ pdf_output = False      # a boolean stating whether to also output pdf versions
     if tryatnf: # try getting ATNF info now
       pinfo = get_atnf_info(pname)
       if pinfo is not None:
-        dist, p1_I, assoc = pinfo # unpack values
+        dist, p1_I, assoc, atnfurlref = pinfo # unpack values
 
     # if distance is in the par file use that instead
     if par['DIST']:
