@@ -512,9 +512,9 @@ REAL8 priorFunction( LALInferenceRunState *runState, LALInferenceVariables *para
           }
         }
       }
-      /* check if using a 1d Gaussian Mixture Model prior */
-      else if( LALInferenceCheck1DGMMPrior(runState->priorArgs, item->name) ){
-        prior += LALInference1DGMMPrior( runState->priorArgs, item->name, value );
+      /* check if using a Gaussian Mixture Model prior */
+      else if( LALInferenceCheckGMMPrior(runState->priorArgs, item->name) ){
+        prior += LALInferenceGMMPrior( runState->priorArgs, item->name, value );
       }
       /* check for log(uniform) prior */
       else if( LALInferenceCheckLogUniformPrior(runState->priorArgs, item->name) ){
@@ -551,7 +551,7 @@ REAL8 priorFunction( LALInferenceRunState *runState, LALInferenceVariables *para
     LALInferenceGetCorrelatedPrior( runState->priorArgs, corlist->data[0], &cor, &invcor, &mu, &sigma, &idx );
 
     /* get the log prior (this only works properly if the parameter values have been prescaled so as to be from a
-     * Gaussian of zero mean and unit variance, which happens on line 473) */
+     * Gaussian of zero mean and unit variance, which happens on line 510) */
     vals = gsl_vector_view_array( corVals->data, corVals->length );
 
     XLAL_CALLGSL( gsl_blas_dgemv(CblasNoTrans, 1., invcor, &vals.vector, 0., vm) );
@@ -931,7 +931,7 @@ UINT4 in_range( LALInferenceVariables *priors, LALInferenceVariables *params ){
       if ( !strcmp(item->name, "H0") || !strcmp(item->name, "Q22") || !strcmp(item->name, "DIST") ||
            !strcmp(item->name, "PX") || !strcmp(item->name, "CGW") || !strncmp(item->name, "ECC", sizeof(CHAR)*3) ||
            !strncmp(item->name, "A1", sizeof(CHAR)*2) || !strcmp(item->name, "MTOT") || !strcmp(item->name, "M2") ){
-          return 0;
+        return 0;
       }
     }
 
