@@ -64,7 +64,7 @@ void get_pulsar_model( LALInferenceModel *model ){
         REAL8 dist = LALInferenceGetREAL8Variable( model->params, "DIST" );
         REAL8 f0 = LALInferenceGetREAL8Variable( model->params, "F0" );
         REAL8 h0val = Q22*sqrt(8.*LAL_PI/15.)*16.*LAL_PI*LAL_PI*LAL_G_SI*f0*f0/(LAL_C_SI*LAL_C_SI*LAL_C_SI*LAL_C_SI*dist);
-        PulsarAddParam( pars, "H0", &h0val, PULSARTYPE_REAL8_t );
+        PulsarAddREAL8Param( pars, "H0", h0val );
       }
       else{
         XLAL_ERROR_VOID( XLAL_EINVAL, "Error... using mass quadrupole, Q22, but no distance or frequency given!" );
@@ -85,7 +85,7 @@ void get_pulsar_model( LALInferenceModel *model ){
     /* check whether using cos(theta) or theta as the variable (defaulting to cos(theta) being the value that is set */
     if ( LALInferenceCheckVariableNonFixed( model->params, "THETA" ) ){
       REAL8 costheta = cos(LALInferenceGetREAL8Variable( model->params, "THETA" ));
-      PulsarAddParam( pars, "COSTHETA", &costheta, PULSARTYPE_REAL8_t );
+      PulsarAddREAL8Param( pars, "COSTHETA", costheta );
     }
     else{ add_pulsar_parameter( model->params, pars, "COSTHETA" ); }
     add_pulsar_parameter( model->params, pars, "PHI0" ); /* note that this is the rotational phase */
@@ -93,7 +93,7 @@ void get_pulsar_model( LALInferenceModel *model ){
     /* check whether using cos(iota) or iota as the variable (defaulting to cos(iota) being the value that is set) */
     if ( LALInferenceCheckVariableNonFixed( model->params, "IOTA" ) ){
       REAL8 cosiota = cos(LALInferenceGetREAL8Variable( model->params, "IOTA" ));
-      PulsarAddParam( pars, "COSIOTA", &cosiota, PULSARTYPE_REAL8_t );
+      PulsarAddREAL8Param( pars, "COSIOTA", cosiota );
     }
     else{ add_pulsar_parameter( model->params, pars, "COSIOTA" ); }
 
@@ -142,14 +142,14 @@ void get_pulsar_model( LALInferenceModel *model ){
     /* check whether using cos(theta) or theta as the variable (defaulting to cos(theta) being the value that is set */
     if ( LALInferenceCheckVariableNonFixed( model->params, "IOTA" ) ){
       REAL8 cosiota = cos(LALInferenceGetREAL8Variable( model->params, "IOTA" ));
-      PulsarAddParam( pars, "COSIOTA", &cosiota, PULSARTYPE_REAL8_t );
+      PulsarAddREAL8Param( pars, "COSIOTA", cosiota );
     }
     else{ add_pulsar_parameter( model->params, pars, "COSIOTA" ); }
 
     if( LALInferenceCheckVariable( model->ifo->params, "biaxial" ) ){
       /* use complex amplitude parameterisation, but set up for a biaxial star */
       REAL8 phi22 = 2.*LALInferenceGetREAL8Variable( model->params, "PHI21" );
-      PulsarAddParam( pars, "PHI22", &phi22, PULSARTYPE_REAL8_t );
+      PulsarAddREAL8Param( pars, "PHI22", phi22 );
     }
     else{
       add_pulsar_parameter( model->params, pars, "PHI22" );
@@ -180,8 +180,10 @@ void get_pulsar_model( LALInferenceModel *model ){
       REAL8 f0fixed = LALInferenceGetREAL8Variable( model->params, varname );
       deltafreqs->data[i] = f0new-f0fixed; /* frequency (derivative) difference */
     }
-    PulsarAddParam( pars, "F", &freqs, PULSARTYPE_REAL8Vector_t );
-    PulsarAddParam( pars, "DELTAF", &deltafreqs, PULSARTYPE_REAL8Vector_t );
+    PulsarAddREAL8VectorParam( pars, "F", (const REAL8Vector *)freqs );
+    PulsarAddREAL8VectorParam( pars, "DELTAF", (const REAL8Vector *)deltafreqs );
+    XLALDestroyREAL8Vector( freqs );
+    XLALDestroyREAL8Vector( deltafreqs );
   }
 
   /* check if there are glitch parameters */
@@ -199,7 +201,8 @@ void get_pulsar_model( LALInferenceModel *model ){
           }
           else{ gl->data[j] = 0.; }
         }
-        PulsarAddParam( pars, glitchpars[i], &gl, PULSARTYPE_REAL8Vector_t );
+        PulsarAddREAL8VectorParam( pars, glitchpars[i], (const REAL8Vector *)gl );
+        XLALDestroyREAL8Vector( gl );
       }
     }
   }
@@ -209,7 +212,7 @@ void get_pulsar_model( LALInferenceModel *model ){
     /* binary system model - NOT pulsar model */
     CHAR binary[PULSAR_PARNAME_MAX];
     snprintf(binary, PULSAR_PARNAME_MAX*sizeof(CHAR), "%s", *(CHAR**)LALInferenceGetVariable( model->ifo->params, "BINARY" ));
-    PulsarAddParam( pars, "BINARY", &binary, PULSARTYPE_string_t );
+    PulsarAddStringParam( pars, "BINARY", binary );
 
     add_pulsar_parameter( model->params, pars, "ECC" );
     add_pulsar_parameter( model->params, pars, "OM" );
@@ -260,7 +263,8 @@ void get_pulsar_model( LALInferenceModel *model ){
         snprintf(varname, sizeof(varname), "FB%u", i);
         fb->data[i] = LALInferenceGetREAL8Variable( model->params, varname );
       }
-      PulsarAddParam( pars, "FB", &fb, PULSARTYPE_REAL8Vector_t );
+      PulsarAddREAL8VectorParam( pars, "FB", (const REAL8Vector *)fb );
+      XLALDestroyREAL8Vector( fb );
     }
   }
 
@@ -292,9 +296,9 @@ void set_nonGR_model_parameters( PulsarParameters *pars, char* nonGRmodel ){
     REAL8 hVectorX = h0 * siniota;
     REAL8 hVectorY = h0 * siniota * cosiota;
     REAL8 psiVector = LAL_PI_2;
-    PulsarAddParam( pars, "HVECTORX", &hVectorX, PULSARTYPE_REAL8_t );
-    PulsarAddParam( pars, "HVECTORY", &hVectorY, PULSARTYPE_REAL8_t );
-    PulsarAddParam( pars, "PSIVECTOR", &psiVector, PULSARTYPE_REAL8_t );
+    PulsarAddREAL8Param( pars, "HVECTORX", hVectorX );
+    PulsarAddREAL8Param( pars, "HVECTORY", hVectorY );
+    PulsarAddREAL8Param( pars, "PSIVECTOR", psiVector );
   }
   else if( isEGR == 0 ) {
     /** GR plus an unconstrained non-GR modes
@@ -305,9 +309,9 @@ void set_nonGR_model_parameters( PulsarParameters *pars, char* nonGRmodel ){
     REAL8 hPlus = 0.5 * h0 * (1. + cosiota * cosiota);
     REAL8 hCross = h0 * cosiota;
     REAL8 psiTensor = -LAL_PI_2;
-    PulsarAddParam( pars, "HPLUS", &hPlus, PULSARTYPE_REAL8_t );
-    PulsarAddParam( pars, "HCROSS", &hCross, PULSARTYPE_REAL8_t );
-    PulsarAddParam( pars, "PSITENSOR", &psiTensor, PULSARTYPE_REAL8_t );
+    PulsarAddREAL8Param( pars, "HPLUS", hPlus );
+    PulsarAddREAL8Param( pars, "HCROSS", hCross );
+    PulsarAddREAL8Param( pars, "PSITENSOR", psiTensor );
   } else {
     XLAL_ERROR_VOID( XLAL_EINVAL, "Unrecognized non-GR model. Currently supported: enhanced GR (EGR), G4v, or no argument for full search." );
   }
@@ -323,7 +327,7 @@ void set_nonGR_model_parameters( PulsarParameters *pars, char* nonGRmodel ){
  */
 void add_pulsar_parameter( LALInferenceVariables *var, PulsarParameters *params, const CHAR *parname ){
   REAL8 par = LALInferenceGetREAL8Variable( var, parname );
-  PulsarAddParam( params, parname, &par, PULSARTYPE_REAL8_t );
+  PulsarAddREAL8Param( params, parname, par );
 }
 
 
@@ -362,7 +366,7 @@ void add_variable_parameter( PulsarParameters *params, LALInferenceVariables *va
  * This does not try to undo the signal modulation in the data, but instead replicates the modulation in the model,
  * hence the positive phase difference rather than a negative phase in the exponential function.
  *
- * \param params [in] A \c BinaryPulsarParams structure containing the model parameters
+ * \param params [in] A \c PulsarParameters structure containing the model parameters
  * \param ifo [in] The ifo model structure containing the detector paramters and buffers
  *
  * \sa get_amplitude_model
@@ -495,58 +499,57 @@ REAL8Vector *get_phase_model( PulsarParameters *params, LALInferenceIFOModel *if
   }
 
   /* get vector of frequencies and frequency differences */
-  REAL8Vector *freqs = PulsarGetREAL8VectorParam( params, "F" );
-  REAL8Vector *deltafs = PulsarGetREAL8VectorParam( params, "DELTAF" );
+  const REAL8Vector *freqs = PulsarGetREAL8VectorParam( params, "F" );
+  const REAL8Vector *deltafs = PulsarGetREAL8VectorParam( params, "DELTAF" );
 
   if ( PulsarCheckParam( params, "BINARY" ) ){ isbinary = 1; } /* see if pulsar is in binary */
   if ( PulsarCheckParam( params, "GLEP" ) ){ /* see if pulsar has glitch parameters */
-    REAL8Vector *glpars = NULL;
-    glpars = PulsarGetREAL8VectorParam( params, "GLEP" );
-    glnum = glpars->length;
+    const REAL8Vector *gleppars = PulsarGetREAL8VectorParam( params, "GLEP" );
+    glnum = gleppars->length;
 
     /* get epochs */
     glep = XLALCalloc(glnum, sizeof(REAL8)); /* initialise to zeros */
-    for ( i=0; i<glpars->length; i++ ){ glep[i] = glpars->data[i]; }
+    for ( i=0; i<gleppars->length; i++ ){ glep[i] = gleppars->data[i]; }
 
     /* get phase offsets */
     glph = XLALCalloc(glnum, sizeof(REAL8)); /* initialise to zeros */
     if ( PulsarCheckParam( params, "GLPH" ) ){
-      glpars = PulsarGetREAL8VectorParam( params, "GLPH" );
+      const REAL8Vector *glpars = PulsarGetREAL8VectorParam( params, "GLPH" );
       for ( i=0; i<glpars->length; i++ ){ glph[i] = glpars->data[i]; }
     }
 
     /* get frequencies offsets */
     glf0 = XLALCalloc(glnum, sizeof(REAL8)); /* initialise to zeros */
     if ( PulsarCheckParam( params, "GLF0" ) ){
-      glpars = PulsarGetREAL8VectorParam( params, "GLF0" );
+      const REAL8Vector *glpars = PulsarGetREAL8VectorParam( params, "GLF0" );
       for ( i=0; i<glpars->length; i++ ){ glf0[i] = glpars->data[i]; }
     }
 
     /* get frequency derivative offsets */
     glf1 = XLALCalloc(glnum, sizeof(REAL8)); /* initialise to zeros */
     if ( PulsarCheckParam( params, "GLF1" ) ){
-      glpars = PulsarGetREAL8VectorParam( params, "GLF1" );
+      const REAL8Vector *glpars = PulsarGetREAL8VectorParam( params, "GLF1" );
       for ( i=0; i<glpars->length; i++ ){ glf1[i] = glpars->data[i]; }
     }
 
     /* get second frequency derivative offsets */
     glf2 = XLALCalloc(glnum, sizeof(REAL8)); /* initialise to zeros */
     if ( PulsarCheckParam( params, "GLF2" ) ){
-      glpars = PulsarGetREAL8VectorParam( params, "GLF2" );
+      const REAL8Vector *glpars = PulsarGetREAL8VectorParam( params, "GLF2" );
       for ( i=0; i<glpars->length; i++ ){ glf2[i] = glpars->data[i]; }
     }
 
     /* get decaying frequency component offset derivative */
     glf0d = XLALCalloc(glnum, sizeof(REAL8)); /* initialise to zeros */
     if ( PulsarCheckParam( params, "GLF0D" ) ){
-      glpars = PulsarGetREAL8VectorParam( params, "GLF0D" );
+      const REAL8Vector *glpars = PulsarGetREAL8VectorParam( params, "GLF0D" );
       for ( i=0; i<glpars->length; i++ ){ glf0d[i] = glpars->data[i]; }
     }
 
     /* get decaying frequency component decay time constant */
     gltd = XLALCalloc(glnum, sizeof(REAL8)); /* initialise to zeros */
     if ( PulsarCheckParam( params, "GLTD" ) ){
-      glpars = PulsarGetREAL8VectorParam( params, "GLTD" );
+      const REAL8Vector *glpars = PulsarGetREAL8VectorParam( params, "GLTD" );
       for ( i=0; i<glpars->length; i++ ){ gltd[i] = glpars->data[i]; }
     }
   }
@@ -768,260 +771,6 @@ REAL8Vector *get_bsb_delay( PulsarParameters *pars, LIGOTimeGPSVector *datatimes
 }
 
 
-/**
- * \brief The amplitude model of a complex heterodyned triaxial neutron star
- *
- * This function calculates the complex heterodyned time series model for a triaxial neutron star (see
- * [\cite DupuisWoan2005]). It is defined as:
- * \f{eqnarray}{
- * y(t) & = & \frac{h_0}{2} \left( \frac{1}{2}F_+(t,\psi)
- * (1+\cos^2\iota)\exp{i\phi_0} - iF_{\times}(t,\psi)\cos{\iota}\exp{i\phi_0}
- * \right),
- * \f}
- * where \f$F_+\f$ and \f$F_{\times}\f$ are the antenna response functions for the plus and cross polarisations.
- *
- * The antenna pattern functions a(t) and b(t) are contained in a 1D lookup table, so within this function
- * the correct value for the given time is interpolated from this lookup table using linear interpolation.
- *
- * \param pars [in] A set of pulsar parameters
- * \param ifo [in] The ifo parameters giving information on the data and detector
- *
- * DEPRECATED: use \c get_amplitude_model instead.
- */
-void get_triaxial_amplitude_model( BinaryPulsarParams pars, LALInferenceIFOModel *ifo ){
-  INT4 i = 0, length;
-
-  REAL8 tsteps, tsv;
-  INT4 timebinMin, timebinMax;
-  REAL8 plus, cross, plusT, crossT;
-  REAL8 plus00, plus01, cross00, cross01;
-  REAL8 timeScaled;
-  REAL8 timeMin, timeMax;
-  REAL8 T;
-  REAL8 Xplus, Xcross;
-  COMPLEX16 expiphi, Xpexpphi, Xcexpphi;
-  REAL8 twopsi = 0.;
-  REAL4 c2psi = 0., s2psi = 0.;
-
-  REAL8Vector *LU_Fplus = NULL, *LU_Fcross = NULL;
-  REAL8Vector *sidDayFrac = NULL;
-
-  length = ifo->times->length;
-
-  /* set lookup table parameters */
-  tsteps = *(INT4*)LALInferenceGetVariable( ifo->params, "timeSteps" );
-
-  LU_Fplus = *(REAL8Vector **)LALInferenceGetVariable( ifo->params, "a_response" );
-  LU_Fcross = *(REAL8Vector **)LALInferenceGetVariable( ifo->params, "b_response" );
-
-  /* get the sidereal time since the initial data point % sidereal day */
-  sidDayFrac = *(REAL8Vector**)LALInferenceGetVariable( ifo->params, "siderealDay" );
-
-  expiphi = cexp( I * pars.phi0 );
-
-  /************************* CREATE MODEL *************************************/
-  /* This model is a complex heterodyned time series for a triaxial neutron star emitting at twice its rotation
-   * frequency (as defined in Dupuis and Woan, PRD, 2005):
-   *    h(t) = (h0/2) * ((1/2)*F+(t)*(1+cos(iota)^2)*exp(i*phi0) - i*Fx(t)*cos(iota)*exp(i*phi0))
-   ****************************************************************************/
-  Xplus = 0.25*(1.+pars.cosiota*pars.cosiota)*pars.h0;
-  Xcross = 0.5*pars.cosiota*pars.h0;
-  Xpexpphi = Xplus*expiphi;
-  Xcexpphi = Xcross*expiphi;
-  twopsi = 2.*pars.psi;
-  XLAL_CHECK_VOID( XLALSinCosLUT( &s2psi, &c2psi, twopsi ) == XLAL_SUCCESS, XLAL_EFUNC );
-
-  tsv = LAL_DAYSID_SI / tsteps;
-
-  for( i=0; i<length; i++ ){
-    /* set the time bin for the lookup table */
-    /* sidereal day in secs*/
-    T = sidDayFrac->data[i];
-    timebinMin = (INT4)fmod( floor(T / tsv), tsteps );
-    timeMin = timebinMin*tsv;
-    timebinMax = (INT4)fmod( timebinMin + 1, tsteps );
-    timeMax = timeMin + tsv;
-
-    /* get values of matrix for linear interpolation */
-    plus00 = LU_Fplus->data[timebinMin];
-    plus01 = LU_Fplus->data[timebinMax];
-
-    cross00 = LU_Fcross->data[timebinMin];
-    cross01 = LU_Fcross->data[timebinMax];
-
-    /* rescale time for linear interpolation on a unit square */
-    timeScaled = (T - timeMin)/(timeMax - timeMin);
-
-    plus = plus00 + (plus01-plus00)*timeScaled;
-    cross = cross00 + (cross01-cross00)*timeScaled;
-
-    plusT = plus*c2psi + cross*s2psi;
-    crossT = cross*c2psi - plus*s2psi;
-
-    /* create the complex signal amplitude model */
-    ifo->compTimeSignal->data->data[i] = plusT*Xpexpphi - I*crossT*Xcexpphi;
-  }
-}
-
-
-/**
- * \brief The amplitude model of a complex heterodyned signal from a NS rotating about the pinning axis of its pinned
- * superfluid component.
- *
- * This function calculates the complex heterodyned time series model for a triaxial neutron star rotating about the
- * pinning axis of its pinned superfluid component.
- *
- * Unlike the standard triaxial model, this model has emission at f and 2f, therefore this model function processes two
- * sets of data per detector. In this model the \f$\phi_0\f$ parameter is the initial phase for the \f$l=m=2\f$ harmonic
- * (i.e. equivalent to the phase at 2f for the triaxial model).
- *
- * As for the standard triaxial model, the antenna pattern functions are contained in a 1D lookup table, so within this
- * function the correct value for the given time is interpolated from this lookup table using linear
- * interpolation.
- *
- * \param pars [in] A set of pulsar parameters
- * \param ifo  [in] The ifo model containing detector-specific parameters
- *
- * DEPRECATED: use \c get_amplitude_model instead.
- */
-void get_pinsf_amplitude_model( BinaryPulsarParams pars, LALInferenceIFOModel *ifo ){
-  INT4 i = 0, length;
-
-  REAL8 tsteps, tsv;
-  INT4 timebinMin, timebinMax;
-  REAL8 plus00, plus01, cross00, cross01;
-  REAL8 timeScaled;
-  REAL8 timeMin, timeMax;
-  REAL8 plus, cross;
-  REAL8 T;
-  REAL8 Xplusf, Xcrossf, Xplus2f, Xcross2f;
-  REAL8 A21, A22, B21, B22;
-  COMPLEX16 ePhi, e2Phi;
-  REAL8 iota = acos(pars.cosiota), theta = acos(pars.costheta);
-  REAL8 siniota = sin(iota);
-  REAL8 sintheta = sin(theta), sin2theta = sin( 2.*theta );
-  REAL4 coslambda, sinlambda;
-  REAL8 sin2lambda = sin( 2.*pars.lambda );
-  REAL8 f2_r;
-
-  REAL8Vector *LU_Fplus = NULL, *LU_Fcross = NULL;
-  REAL8Vector *sidDayFrac1 = NULL;
-  REAL8Vector *sidDayFrac2 = NULL;
-  REAL8 twopsi = 0., plusT = 0., crossT = 0.;
-  REAL4 c2psi = 0., s2psi = 0.;
-
-  /* set lookup table parameters */
-  tsteps = *(INT4*)LALInferenceGetVariable( ifo->params, "timeSteps" );
-
-  twopsi = 2.*pars.psi;
-  XLAL_CHECK_VOID( XLALSinCosLUT( &s2psi, &c2psi, twopsi ) == XLAL_SUCCESS, XLAL_EFUNC );
-
-  LU_Fplus = *(REAL8Vector **)LALInferenceGetVariable( ifo->params, "a_response" );
-  LU_Fcross = *(REAL8Vector **)LALInferenceGetVariable( ifo->params, "b_response");
-  /* get the sidereal time since the initial data point % sidereal day */
-  sidDayFrac1 = *(REAL8Vector**)LALInferenceGetVariable( ifo->params, "siderealDay" );
-
-  /* phi0 here the GW phase for the l=m=2 mode */
-  ePhi = cexp( 0.5 * pars.phi0 * I );
-  e2Phi = cexp( pars.phi0 * I );
-
-  XLAL_CHECK_VOID( XLALSinCosLUT( &sinlambda, &coslambda, pars.lambda ) == XLAL_SUCCESS, XLAL_EFUNC );
-
-  /* f^2 / r */
-  f2_r = pars.f0 * pars.f0 / pars.dist;
-
-  /************************* CREATE MODEL *************************************
-   * This model is a complex heterodyned time series for a pinned superfluid neutron star emitting at its roation
-   * frequency and twice its rotation frequency (as originally defined in Jones 2009, but using Eqns 35-38 of Jones
-   * 2012 LIGO DCC T1200265-v3).
-   ****************************************************************************/
-  Xplusf = -( f2_r / 2. ) * siniota * pars.cosiota;
-  Xcrossf = ( f2_r / 2. ) * siniota;
-  Xplus2f = -f2_r * ( 1. + pars.cosiota * pars.cosiota );
-  Xcross2f = 2. * f2_r * pars.cosiota;
-
-  A21 = pars.I21 * sin2lambda * sintheta;
-  B21 = ( pars.I21 * coslambda * coslambda - pars.I31 ) * sin2theta;
-
-  A22 = pars.I21 * ( sinlambda * sinlambda - coslambda * coslambda * pars.costheta * pars.costheta ) -
-    pars.I31 * sintheta * sintheta;
-  B22 = pars.I21 * sin2lambda * pars.costheta;
-
-  tsv = LAL_DAYSID_SI / tsteps;
-
-  /*--------------------------------------------------------------------------*/
-  /* set model for 1f component */
-  length = ifo->times->length;
-
-  for( i=0; i<length; i++ ){
-    /* set the time bin for the lookup table */
-    /* sidereal day in secs*/
-    T = sidDayFrac1->data[i];
-    timebinMin = (INT4)fmod( floor(T / tsv), tsteps );
-    timeMin = timebinMin*tsv;
-    timebinMax = (INT4)fmod( timebinMin + 1, tsteps );
-    timeMax = timeMin + tsv;
-
-    /* get values of matrix for linear interpolation */
-    plus00 = LU_Fplus->data[timebinMin];
-    plus01 = LU_Fplus->data[timebinMax];
-
-    cross00 = LU_Fcross->data[timebinMin];
-    cross01 = LU_Fcross->data[timebinMax];
-
-    /* rescale time for bilinear interpolation on a unit square */
-    timeScaled = (T - timeMin)/(timeMax - timeMin);
-
-    plus = plus00 + (plus01-plus00)*timeScaled;
-    cross = cross00 + (cross01-cross00)*timeScaled;
-
-    plusT = plus*c2psi + cross*s2psi;
-    crossT = cross*c2psi - plus*s2psi;
-
-    /* create the complex signal amplitude model at f */
-    ifo->compTimeSignal->data->data[i] = ( plusT * Xplusf * ePhi * ( A21 - I * B21 ) ) +
-                                         ( crossT * Xcrossf * ePhi * ( B21 + I * A21 ) );
-  }
-
-  /*--------------------------------------------------------------------------*/
-  /* set model for 2f component */
-  length = ifo->next->times->length;
-
-  sidDayFrac2 = *(REAL8Vector**)LALInferenceGetVariable( ifo->next->params, "siderealDay" );
-
-  for( i=0; i<length; i++ ){
-    /* set the time bin for the lookup table */
-    /* sidereal day in secs*/
-    T = sidDayFrac2->data[i];
-    timebinMin = (INT4)fmod( floor(T / tsv), tsteps );
-    timeMin = timebinMin*tsv;
-    timebinMax = (INT4)fmod( timebinMin + 1, tsteps );
-    timeMax = timeMin + tsv;
-
-    /* get values of matrix for linear interpolation */
-    plus00 = LU_Fplus->data[timebinMin];
-    plus01 = LU_Fplus->data[timebinMax];
-
-    cross00 = LU_Fcross->data[timebinMin];
-    cross01 = LU_Fcross->data[timebinMax];
-
-    /* rescale time for bilinear interpolation on a unit square */
-    timeScaled = (T - timeMin)/(timeMax - timeMin);
-
-    plus = plus00 + (plus01-plus00)*timeScaled;
-    cross = cross00 + (cross01-cross00)*timeScaled;
-
-    plusT = plus*c2psi + cross*s2psi;
-    crossT = cross*c2psi - plus*s2psi;
-
-    /* create the complex signal amplitude model at 2f */
-    ifo->next->compTimeSignal->data->data[i] = ( plusT * Xplus2f * e2Phi * ( A22 - I * B22 ) ) +
-                                               ( crossT * Xcross2f * e2Phi * ( B22 + I * A22 ) );
-  }
-  /*--------------------------------------------------------------------------*/
-}
-
-
 /**
  * \brief The amplitude model of a complex heterodyned signal from the \f$l=2, m=1,2\f$ harmonics of a rotating neutron
  * star.
@@ -1205,15 +954,11 @@ void get_amplitude_model( PulsarParameters *pars, LALInferenceIFOModel *ifo ){
       }
       else{ /* just have to calculate the values to multiply the pre-summed data */
         /* for tensor-only models (e.g. the default of GR) calculate the two components of
-         * the single model value - things multplied by a(t) and things multiplied by b(t)
-         * (both these will have real and imaginary components:
-         * h(t) = a(t)*(Cplus*cos(2psi) - Ccross*sin(2psi)) +
-         *        b(t)*(Cplus*sin(2psi) + Ccross*cos(2psi))
-         *
-         * For scalar and vector modes also calculate the four addiational components:
-         * h(t)^V = aV(t)*(Cx*cos(psi) - Cy*sin(psi)) +
-         *          bV(t)*(Cy*sin(psi) + Cy*cos(psi)),
-         * h(t)^S = aS(t)*Cb + bS(t)*Cl.
+         * the single model value - things multiplied by a(t) and things multiplied by b(t)
+         * (both these will have real and imaginary components). NOTE: the values input into
+         * ifo->compTimeSignal->data->data are not supposed to be identical to the above
+         * relationships between the amplitudes and polarisation angles, as these are the
+         * multiplicative coefficients of the a(t) and b(t) summations.
          */
 
         /* put multiples of a(t) in first value and b(t) in second */
@@ -1474,10 +1219,10 @@ void invert_source_params( PulsarParameters *params ){
   if ( h0 != 0.){
     phi22 = 2.*phi0;
     phi22 = phi22 - LAL_TWOPI*floor(phi22/LAL_TWOPI);
-    PulsarAddParam( params, "PHI22", &phi22, PULSARTYPE_REAL8_t );
+    PulsarAddREAL8Param( params, "PHI22", phi22 );
 
     C22 = -0.5*h0; /* note the change in sign so that the triaxial model conforms to the convertion in JKS98 */
-    PulsarAddParam( params, "C22", &C22, PULSARTYPE_REAL8_t );
+    PulsarAddREAL8Param( params, "C22", C22 );
   }
   else if ( ( I21 != 0. || I31 != 0. ) && ( C22 == 0. && C21 == 0. ) ) {
     sinlambda = sin( lambda );
@@ -1505,13 +1250,13 @@ void invert_source_params( PulsarParameters *params ){
     C22 = 2.*sqrt( A222 + B222 );
     C21 = 2.*sqrt( A212 + B212 );
 
-    PulsarAddParam( params, "C22", &C22, PULSARTYPE_REAL8_t );
-    PulsarAddParam( params, "C21", &C21, PULSARTYPE_REAL8_t );
+    PulsarAddREAL8Param( params, "C22", C22 );
+    PulsarAddREAL8Param( params, "C21", C21 );
 
     phi22 = fmod( 2.*phi0 - atan2( B22, A22 ), LAL_TWOPI );
     phi21 = fmod( phi0 - atan2( B21, A21 ), LAL_TWOPI );
 
-    PulsarAddParam( params, "PHI22", &phi22, PULSARTYPE_REAL8_t );
-    PulsarAddParam( params, "PHI21", &phi21, PULSARTYPE_REAL8_t );
+    PulsarAddREAL8Param( params, "PHI22", phi22 );
+    PulsarAddREAL8Param( params, "PHI21", phi21 );
   }
 }
