@@ -76,7 +76,10 @@
  *
  * If using real data the files must be specified in the \c input-files command line argument - these should be comma
  * separated for multiple files and be in the same order at the associated detector from which they came given by the
- * \c detectors command.
+ * \c detectors command. Any potentially spuriously large data values, with an absolute value of greater than 1e-18
+ * will be vetoed when the data in read in. If requiring a different threshold for the veto (e.g., you are working
+ * with very low frequency data, or simulated data with a different scaling) then the value can be changed by setting
+ * it with the \c --veto-threshold command line argument.
  *
  * The function also checks that valid Earth and Sun ephemeris files (from the lalpulsar suite) are set with the \c
  * ephem-earth and \c ephem-sun arguments, and that a valid output file for the nested samples is set via the \c outfile
@@ -114,7 +117,7 @@ void read_pulsar_data( LALInferenceRunState *runState ){
   REAL8 *fstarts = NULL, *flengths = NULL, *fdt = NULL;
 
   CHAR dets[MAXDETS][256];
-  INT4 numDets = 0, i = 0, numPsds = 0, numLengths = 0, numStarts = 0;
+  INT4 numDets = 1, i = 0, numPsds = 0, numLengths = 0, numStarts = 0;
   INT4 numDt = 0, count = 0;
   UINT4 maxlen = 0;
 
@@ -164,7 +167,6 @@ void read_pulsar_data( LALInferenceRunState *runState ){
     modelFreqFactors->data[i] = atof(harmval);
   }
   XLALFree( tmpharms );
-  XLALFree( tmpharm );
   XLALFree( harmonics );
 
   ppt = LALInferenceGetProcParamVal( runState->commandLine, "--par-file" );
@@ -172,7 +174,7 @@ void read_pulsar_data( LALInferenceRunState *runState ){
   parFile = ppt->value;
 
   /* get the pulsar parameters to give a value of f */
-  pulsar = XLALReadTEMPOParFileNew( parFile );
+  pulsar = XLALReadTEMPOParFile( parFile );
 
   /* get the detectors - must */
   ppt = LALInferenceGetProcParamVal( commandLine, "--detectors" );
@@ -205,6 +207,7 @@ void read_pulsar_data( LALInferenceRunState *runState ){
       fprintf(stderr, "Error... too many detectors specified. Increase MAXDETS to be greater than %d if necessary.\n", MAXDETS);
       exit(0);
     }
+
     /*------------------------------------------------------------------------*/
     /* get noise psds if specified */
     ppt = LALInferenceGetProcParamVal(commandLine,"--fake-psd");
@@ -375,7 +378,6 @@ number of detectors specified (no. dets =%d)\n", ml, ml, numDets);
     else{ /* set default (60 sesonds) */
       for(i = 0; i < ml*numDets; i++) { fdt[i] = 60.; }
     }
-
   }
   /*psds set and timestamps set.*/
   /*====================================================================*/
@@ -446,6 +448,14 @@ detectors specified (no. dets =%d)\n", ml, ml, numDets);
     }
   }
 
+  /* ignore data with absolute value larger than some input value (defaults to 1e-18) to chop out spurious extremely load noise */
+  ppt = LALInferenceGetProcParamVal( commandLine, "--veto-threshold" );
+  REAL8 vetothresh = 1e-18;
+  if ( ppt != NULL ) { vetothresh = atof( ppt->value ); }
+
+  /* initialise random number generator if seed is zero */
+  if ( seed == 0 ){ randomParams = XLALCreateRandomParams( 0 ); }
+
   /* read in data, needs to read in two sets of data for each ifo for pinsf model */
   for( i = 0, prev=NULL, prevmodel=NULL ; i < ml*numDets ; i++, prev=ifodata, prevmodel=ifomodel ){
     CHAR *datafile = NULL;
@@ -453,17 +463,17 @@ detectors specified (no. dets =%d)\n", ml, ml, numDets);
     LIGOTimeGPS gpstime;
     REAL8 dataValsRe = 0., dataValsIm = 0., sigmaVals = 0.;
     REAL8Vector *temptimes = NULL;
-    INT4 j = 0, k = 0, datalength = 0;
+    UINT4 j = 0, k = 0, datalength = 0;
     ProcessParamsTable *ppte = NULL, *ppts = NULL, *pptt = NULL;
 
     CHAR *filebuf = NULL;
 
     count = 0;
 
-    /* initialise random number generator */
-    /* Moved into det loop so same random seed can be used with */
-    /* different detector combos and still get same noise realisation */
-    randomParams = XLALCreateRandomParams( seed+i );
+    /* initialise random number generator (if using a non-zero seed).
+     * Moved into det loop so same random seed can be used with
+     * different detector combos and still get same noise realisation */
+    if ( seed != 0 ){ randomParams = XLALCreateRandomParams( seed+i ); }
 
     ifodata = XLALCalloc( 1, sizeof(LALInferenceIFOData) );
     ifodata->likeli_counter = 0;
@@ -575,7 +585,7 @@ detectors specified (no. dets =%d)\n", ml, ml, numDets);
 
       INT4 nvals = 0; /* number of values in a line */
 
-      for ( k = 0; k < (INT4)tlist->nTokens; k++ ){
+      for ( k = 0; k < tlist->nTokens; k++ ){
         /* search for a comment character in the string */
         if ( strchr(tlist->tokens[k], '#') || strchr(tlist->tokens[k], '%') ){ continue; }
         else{ /* read in data from string */
@@ -604,9 +614,21 @@ detectors specified (no. dets =%d)\n", ml, ml, numDets);
             exit(3);
           }
           /* ignore excessively large spurious values as they can screw things up */
-          if ( fabs(dataValsRe) > 1e-18 || fabs(dataValsIm) > 1e-18 ){ continue; }
+          if ( fabs(dataValsRe) > vetothresh || fabs(dataValsIm) > vetothresh ){ continue; }
+
+          /* make sure timestamps are unique */
+          if ( j > 0 ){
+            UINT4 notunique = 0;
+            for ( UINT4 ucount=0; ucount < j; ucount++ ){
+              if ( times == temptimes->data[ucount] ){
+                notunique = 1;
+                break;
+              }
+            }
+            if ( notunique ){ continue; }
+          }
         }
-        /* at this point, wa haven't added this item to the data yet */
+        /* at this point, we haven't added this item to the data yet */
         /* check truncation conditions before doing so */
         if ( LALInferenceGetProcParamVal( commandLine, "--truncate-time" ) ){
           /* assume truncateValue is a GPS time */
@@ -622,7 +644,7 @@ detectors specified (no. dets =%d)\n", ml, ml, numDets);
             break;
           }
         }
-        
+
         j++;
 
         /* dynamically allocate more memory */
@@ -632,7 +654,7 @@ detectors specified (no. dets =%d)\n", ml, ml, numDets);
 
         temptimes = XLALResizeREAL8Vector( temptimes, j );
 
-        // Note: j-1 because we added to j above (553)
+        /* Note: j-1 because we already added to j above */
         temptimes->data[j-1] = times;
 
         /* reheterodyne data if required */
@@ -673,7 +695,6 @@ detectors specified (no. dets =%d)\n", ml, ml, numDets);
           ifodata->compTimeData = XLALResizeCOMPLEX16TimeSeries( ifodata->compTimeData, 0, truncationIndex );
           ifomodel->compTimeSignal = XLALResizeCOMPLEX16TimeSeries( ifomodel->compTimeSignal, 0, truncationIndex );
           ifodata->varTimeData = XLALResizeREAL8TimeSeries( ifodata->varTimeData, 0, truncationIndex );
-
         }
       }
 
@@ -683,26 +704,24 @@ detectors specified (no. dets =%d)\n", ml, ml, numDets);
       ifomodel->times = NULL;
       ifomodel->times = XLALCreateTimestampVector( datalength );
 
-      UINT4 epochint = 0; /* index of the earliest time in the data */
-
       /* fill in time stamps as LIGO Time GPS Vector */
-      REAL8 sampledt = INFINITY; /* sample interval */
       for ( k = 0; k < datalength; k++ ) {
         XLALGPSSetREAL8( &ifomodel->times->data[k], temptimes->data[k] );
-
-        if ( k > 0 ){
-          /* get sample interval from the minimum time difference in the data */
-          if ( temptimes->data[k] - temptimes->data[k-1] < sampledt ) {
-            sampledt = temptimes->data[k] - temptimes->data[k-1];
-          }
-        }
-
-        if ( temptimes->data[k] < temptimes->data[epochint] ){ epochint = k; }
       }
 
-      ifodata->compTimeData->epoch = ifomodel->times->data[epochint];
-      ifomodel->compTimeSignal->epoch = ifomodel->times->data[epochint];
-      ifodata->varTimeData->epoch = ifomodel->times->data[epochint];
+      /* sort temporary time vector into ascending order (to get minimum time difference) */
+      gsl_sort(temptimes->data, 1, datalength);
+
+      REAL8 sampledt = temptimes->data[1] - temptimes->data[0]; /* sample interval */
+      for ( k = 2; k < datalength; k++ ){
+        if ( temptimes->data[i] - temptimes->data[i-1] < sampledt ){
+          sampledt = temptimes->data[i] - temptimes->data[i-1];
+        }
+      }
+
+      XLALGPSSetREAL8( &ifodata->compTimeData->epoch, temptimes->data[0] );
+      XLALGPSSetREAL8( &ifomodel->compTimeSignal->epoch, temptimes->data[0] );
+      XLALGPSSetREAL8( &ifodata->varTimeData->epoch, temptimes->data[0] );
 
       /* check whether to randomise the data by shuffling the time stamps (this will preserve the order of
        * the data for working out stationary chunk, but randomise the signal) */
@@ -715,8 +734,6 @@ detectors specified (no. dets =%d)\n", ml, ml, numDets);
       }
 
       /* add data sample interval */
-      ppt = LALInferenceGetProcParamVal( commandLine, "--sample-interval" );
-      if( ppt ){ sampledt = atof( ppt->value ); }
       LALInferenceAddVariable( ifomodel->params, "dt", &sampledt, LALINFERENCE_REAL8_t, LALINFERENCE_PARAM_FIXED );
 
       XLALDestroyREAL8Vector( temptimes );
@@ -778,6 +795,7 @@ detectors specified (no. dets =%d)\n", ml, ml, numDets);
     ppte = LALInferenceGetProcParamVal( commandLine, "--ephem-earth" );
     ppts = LALInferenceGetProcParamVal( commandLine, "--ephem-sun" );
     pptt = LALInferenceGetProcParamVal( commandLine, "--ephem-timecorr" );
+
     if( ppte && ppts ){
       efile = XLALStringDuplicate( ppte->value );
       sfile = XLALStringDuplicate( ppts->value );
@@ -820,12 +838,13 @@ detectors specified (no. dets =%d)\n", ml, ml, numDets);
     if ( sfile ) { XLALFree( sfile ); }
     if ( tfile ) { XLALFree( tfile ); }
 
-    XLALDestroyRandomParams( randomParams );
+    if ( seed != 0 ) { XLALDestroyRandomParams( randomParams ); }
 
     /* get maximum data length */
     if ( ifodata->compTimeData->data->length > maxlen ) { maxlen = ifodata->compTimeData->data->length; }
   }
 
+  if ( seed == 0 ) { XLALDestroyRandomParams( randomParams ); }
   XLALFree( filestr );
 
   /* chop the data into stationary chunks and also calculate the noise variance if required
@@ -880,6 +899,7 @@ detectors specified (no. dets =%d)\n", ml, ml, numDets);
     }
 
     LALInferenceAddVariable( modeltmp->params, "chunkLength", &chunkLength, LALINFERENCE_UINT4Vector_t, LALINFERENCE_PARAM_FIXED );
+    LALInferenceAddVariable( modeltmp->params, "inputSigma", &inputsigma, LALINFERENCE_INT4_t, LALINFERENCE_PARAM_FIXED );
 
     /* compute the variance */
     if( !inputsigma ){ compute_variance( datatmp, modeltmp ); }
@@ -974,7 +994,7 @@ void setup_from_par_file( LALInferenceRunState *runState )
 /* Generates lookup tables also */
 {
   LALSource psr;
-  PulsarParameters *pulsar;
+  PulsarParameters *pulsar = NULL;
   LALInferenceIFOData *data = runState->data;
   ProcessParamsTable *ppt = NULL;
   REAL8 DeltaT = 0.; /* maximum data time span */
@@ -984,7 +1004,7 @@ void setup_from_par_file( LALInferenceRunState *runState )
   CHAR *parFile = ppt->value;
 
   /* get the pulsar parameters */
-  pulsar = XLALReadTEMPOParFileNew( parFile );
+  pulsar = XLALReadTEMPOParFile( parFile );
 
   REAL8 ra = 0.;
   if ( PulsarCheckParam( pulsar, "RA" ) ) { ra = PulsarGetREAL8Param( pulsar, "RA" ); }
@@ -1030,7 +1050,7 @@ void setup_from_par_file( LALInferenceRunState *runState )
   LALInferenceIFOModel *ifo_model = runState->threads[0]->model->ifo;
   while( data ){
     REAL8Vector *freqFactors = NULL;
-    UINT4 j = 0;
+    UINT4 j = 0, k = 0;
     REAL8 dt = XLALGPSGetREAL8( &ifo_model->times->data[ifo_model->times->length-1] ) - XLALGPSGetREAL8( &ifo_model->times->data[0] );
 
     if ( dt > DeltaT ){ DeltaT = dt; }
@@ -1059,10 +1079,22 @@ void setup_from_par_file( LALInferenceRunState *runState )
 
       if ( glitches ){ LALInferenceAddVariable( ifo_model->params, "GLITCHES", &glitches, LALINFERENCE_UINT4_t, LALINFERENCE_PARAM_FIXED ); }
 
-      dts = get_ssb_delay( pulsar, ifo_model->times, ifo_model->ephem, ifo_model->tdat, ifo_model->ttype, data->detector );
-      LALInferenceAddVariable( ifo_model->params, "ssb_delays", &dts, LALINFERENCE_REAL8Vector_t, LALINFERENCE_PARAM_FIXED );
+      if ( LALInferenceGetProcParamVal( runState->commandLine, "--inject-only" ) && LALInferenceGetProcParamVal( runState->commandLine, "--inject-coarse" ) ){
+        /* use this if just wanting to create an injection that has only been "coarse heterodyned" */
+        dts = XLALCreateREAL8Vector( ifo_model->times->length );
+        if ( binarymodel != NULL ) { bdts = XLALCreateREAL8Vector( ifo_model->times->length ); }
+        /* set the time delays to zero, so they do not get removed during the injected signal generation */
+        for ( k = 0; k < dts->length; k++ ){
+          dts->data[k] = 0.;
+          if ( binarymodel != NULL ) { bdts->data[k] = 0.; }
+        }
+      }
+      else{
+        dts = get_ssb_delay( pulsar, ifo_model->times, ifo_model->ephem, ifo_model->tdat, ifo_model->ttype, data->detector );
+        bdts = get_bsb_delay( pulsar, ifo_model->times, dts, ifo_model->ephem );
+      }
 
-      bdts = get_bsb_delay( pulsar, ifo_model->times, dts, ifo_model->ephem );
+      LALInferenceAddVariable( ifo_model->params, "ssb_delays", &dts, LALINFERENCE_REAL8Vector_t, LALINFERENCE_PARAM_FIXED );
       if ( bdts != NULL ){ LALInferenceAddVariable( ifo_model->params, "bsb_delays", &bdts, LALINFERENCE_REAL8Vector_t, LALINFERENCE_PARAM_FIXED ); }
 
       data = data->next;
