@@ -33,6 +33,10 @@
 /*                          TESTING FUNCTIONS                                 */
 /* *****************************************************************************/
 
+/* upper limit calculation distribution helper function prototypes */
+static double ul_gauss_cdf_function( double x, void *params );
+static double ul_gauss_CDFRoot( double mu, double sigma, double min, double max );
+
 /**
  * \brief A test function to calculate a 1D posterior on a grid
  *
@@ -77,11 +81,6 @@ void gridOutput( LALInferenceRunState *runState ){
     if( ppt2 ){
       parname = XLALStringDuplicate( ppt2->value );
 
-      if( !recognised_parameter( parname ) ){
-        fprintf(stderr, "Error... parameter %s not recognised\n", parname );
-        exit(0);
-      }
-
       sprintf(parscale, "%s_scale", parname);
       sprintf(parmin, "%s_scale_min", parname);
     }
@@ -186,7 +185,7 @@ void gridOutput( LALInferenceRunState *runState ){
  *
  * This is a testing function that can be substituted for the standard
  * likelihood function. It calculates only the \c h0 parameter posterior based
- * on a Gaussian likelihood with mean of 0.5 and standard deviation of 0.025 -
+ * on a Gaussian likelihood with mean of 0.0 and standard deviation of 0.025 -
  * these values can be changed if required. It is just to be used to test the
  * sampling routine (e.g. Nested Sampling) with a well defined likelihood
  * function.
@@ -198,28 +197,170 @@ void gridOutput( LALInferenceRunState *runState ){
  * \return Natural logarithm of the likelihood
  */
 REAL8 test_gaussian_log_likelihood( LALInferenceVariables *vars,
-                                    UNUSED LALInferenceIFOData *data,
+                                    LALInferenceIFOData *data,
                                     LALInferenceModel *get_model ){
   REAL8 loglike = 0.; /* the log likelihood */
 
-  REAL8 like_mean = 0.5;
-  REAL8 like_sigma = 0.025;
-  REAL8 h0 = *(REAL8 *)LALInferenceGetVariable( vars, "h0" );
-  REAL8 h0scale = *(REAL8 *)LALInferenceGetVariable( get_model->ifo->params, "h0_scale" );
-  REAL8 h0min = *(REAL8 *)LALInferenceGetVariable( get_model->ifo->params, "h0_scale_min" );
+  REAL8 like_mean = LALInferenceGetREAL8Variable( vars, "H0MEAN" );
+  REAL8 like_sigma = LALInferenceGetREAL8Variable( vars, "H0SIGMA" );
 
-  get_model = NULL;
+  if ( !LALInferenceCheckVariable( vars, "H0" ) ){
+    fprintf(stderr, "Error... testing Gaussian likelihood required the \"H0\" parameter to be set in the prior file.\n");
+    exit(1);
+  }
 
-  h0 = h0*h0scale + h0min;
+  REAL8 h0 = LALInferenceGetREAL8Variable( vars, "H0" );
 
   /* search over a simple 1D Gaussian with x defined by the h0 variable */
   loglike = -log(sqrt(2.*LAL_PI)*like_sigma);
-  loglike -= (h0-like_mean)*(h0-like_mean) / (2.*like_sigma*like_sigma);
+  loglike -= 0.5*(h0-like_mean)*(h0-like_mean) / (like_sigma*like_sigma);
+  get_model->ifo_loglikelihoods[0] = loglike;
+
+  data->likeli_counter += 1;
 
   return loglike;
 }
 
 
+/**
+ * \brief Output the analytic evidence for the test Gaussian likelihood and a 95% upper limit
+ *
+ * This function calculated the analytical evidence for a given test Gaussian likelihood and
+ * also a 95% upper limit on the likelihood. The values are output to the HDF5 file if given,
+ * but otherwise are just output to screen.
+ *
+ * \param runState [in] The LALInference run state variable
+ */
+void test_gaussian_output( LALInferenceRunState *runState ){
+  ProcessParamsTable *ppt = NULL;
+  FILE *fp = NULL;
+
+  /* get the minimum and maximum ranges for the Gaussian */
+  REAL8 min = 0., max = INFINITY, Z;
+  if( LALInferenceCheckMinMaxPrior( runState->priorArgs, "H0" ) ){
+    LALInferenceGetMinMaxPrior( runState->priorArgs, "H0", &min, &max );
+  }
+  else{
+    fprintf(stderr, "Error... no prior range set for the test Gaussian likelihood");
+    exit(1);
+  }
+
+  /* get mean and standard deviation */
+  REAL8 h0mean = 0., h0sigma = 0., h0sigma2 = 0., h095 = 0.;
+  h0mean = LALInferenceGetREAL8Variable( runState->threads[0]->currentParams, "H0MEAN" );
+  h0sigma = LALInferenceGetREAL8Variable( runState->threads[0]->currentParams, "H0SIGMA" );
+  h0sigma2 = h0sigma*h0sigma;
+
+  /* calculate the log evidence */
+  Z = log(0.5*(erf(LAL_SQRT1_2*(h0mean - min)/h0sigma) - erf(LAL_SQRT1_2*(h0mean - max)/h0sigma)));
+  Z -= log(max-min); /* multiply by prior */
+
+  /* calculate the 95% upper limit */
+  h095 = ul_gauss_CDFRoot(h0mean, h0sigma, min, max);
+
+  /* calculate the KL divergence */
+  REAL8 lnC = -log(max-min); /* log of prior */
+  REAL8 p_Z = exp(lnC - Z); /* prior divided by the evidence */
+  REAL8 L = Z + 0.5*log(LAL_TWOPI*h0sigma2);
+  REAL8 D = (1. + 2.*L)*(erf((h0mean-min)*LAL_SQRT1_2/h0sigma) - erf((h0mean-max)*LAL_SQRT1_2/h0sigma));
+  REAL8 G = (1./(sqrt(LAL_TWOPI)*h0sigma))*((min-h0mean)*exp(-0.5*(min-h0mean)*(min-h0mean)/h0sigma2) - (max-h0mean)*exp(-0.5*(max-h0mean)*(max-h0mean)/h0sigma2));
+  REAL8 KLdiv = -0.25*p_Z*(D + 2.*G);
+
+  /* Open output file (called test_gauss.txt) using the path of the --outfile value */
+  ppt = LALInferenceGetProcParamVal(runState->commandLine, "--outfile");
+  char *outfile = XLALStringDuplicate(ppt->value), *loc = NULL;
+  /* find last '/' and replace with null termination character */
+  loc = strrchr(outfile, '/');
+  if ( loc ){ outfile[strlen(outfile)-strlen(loc)+1] = '\0'; }
+  else{ outfile = NULL; }
+  outfile = XLALStringAppend(outfile, "test_gauss.txt");
+
+  if ( ( fp = fopen(outfile, "w") ) != NULL ){
+    fprintf(fp, "%.12le\t%.12le\t%.12le\n", Z, h095, KLdiv);
+    fclose(fp);
+  }
+  else{
+    fprintf(stderr, "Warning... could not open test Gaussian output file '%s'.", outfile);
+  }
+}
+
+
+typedef struct
+tagul_params{
+  double mu;
+  double sigma;
+  double min;
+  double area;
+} ul_params;
+
+/* internal Gaussian CDF function for 95% upper limit finding */
+double ul_gauss_cdf_function( double x, void *params ){
+  ul_params *p = (ul_params*)params;
+
+  double mu = p->mu;
+  double sigma = p->sigma;
+  double min = p->min;
+  double area = p->area;
+  double ul = 0.95; /* calculating 95% upper limit */
+  double C = 1./(sqrt(2.)*sigma);
+
+  return (0.5*(erf(C*(mu-min)) - erf(C*(mu-x)))/area) - ul;
+}
+
+
+/** \brief Find the root of the Gaussian CDF to give a 95% upper limit
+ *
+ * Use the Steffenson method to find the root of the function defined in \c ul_gauss_function.
+ */
+static double ul_gauss_CDFRoot( double mu, double sigma, double min, double max ){
+  int gslstatus;
+  int iter = 0, max_iter = 100;
+  const gsl_root_fsolver_type *T;
+  gsl_root_fsolver *s;
+  double x_lo, x_hi;
+  double epsrel = 1e-4; /* relative error tolerance */
+
+  double C = 1./(sqrt(2.)*sigma);
+  double area = 0.5*(erf(C*(mu - min)) - erf(C*(mu - max)));
+
+  gsl_function F;
+  ul_params params = {mu, sigma, min, area};
+
+  double x;
+  /* initial bounds of value */
+  x_lo = mu-10.*sigma;
+  x_hi = mu+10.*sigma;
+
+  F.function = &ul_gauss_cdf_function;
+  F.params = &params;
+
+  T = gsl_root_fsolver_brent; /* use Brent method */
+  s = gsl_root_fsolver_alloc(T);
+  gsl_root_fsolver_set (s, &F, x_lo, x_hi);
+
+  do{
+    iter++;
+    gslstatus = gsl_root_fsolver_iterate( s );
+    x = gsl_root_fsolver_root( s );
+    x_lo = gsl_root_fsolver_x_lower (s);
+    x_hi = gsl_root_fsolver_x_upper (s);
+
+    /* test relative error of bounds */
+    gslstatus = gsl_root_test_interval (x_lo, x_hi, 0., epsrel);
+  }
+  while( gslstatus == GSL_CONTINUE && iter < max_iter );
+
+  if ( gslstatus != GSL_SUCCESS ){
+    XLALPrintError("%s: Failed to converge when drawing from Fermi-Dirac distribution.", __func__);
+    XLAL_ERROR_REAL8(XLAL_EFAILED);
+  }
+
+  gsl_root_fsolver_free (s);
+
+  return x;
+}
+
+
 /**
  * \brief Output a number of prior samples based on the initial live points
  *
