@@ -216,7 +216,8 @@ int main(int argc, char **argv)
   UINT4 h=0;
 
   char parname[256];
-  BinaryPulsarParams pulparams[numParFiles];
+  PulsarParameters *pulparams[numParFiles];
+
   /*clear . and .. in directory */
   free(parnamelist[0]);
   free(parnamelist[1]);
@@ -252,8 +253,9 @@ int main(int argc, char **argv)
 	fprintf(stderr,"Error opening file: %s\n", parname);
 	XLAL_ERROR ( XLAL_EIO );
       }
-      /*BinaryPulsarParams pulparams[numParFiles];*/
-      XLALReadTEMPOParFile( &pulparams[h], parname );
+
+      pulparams[h] = XLALReadTEMPOParFile( parname );
+
       fclose( inject );
       /*fprintf(stderr,"You have now read in %s, saved in index %i", parname, h);*/
 
@@ -362,7 +364,7 @@ int main(int argc, char **argv)
             fprintf (frames, "%s\n", gwfnamelist[k]->d_name);
 	    fclose(frames);
           }
-          
+
           /* </failed file> */
           XLALDestroyREAL8TimeSeries( gwfseries );
 	  continue; /*don't exit program if .gwf file fails, continue through*/
@@ -387,7 +389,7 @@ int main(int argc, char **argv)
 
 	/* read in and test generated frame with XLAL function*/
 
-	LALFrameH *outFrame   = NULL;        /* frame data structure */     
+	LALFrameH *outFrame   = NULL;        /* frame data structure */
 
 	if ((outFrame = XLALFrameNew(&epoch,(REAL8)ndata,"CW_INJ",0,0,detflags)) == NULL) {
 	  LogPrintf(LOG_CRITICAL, "%s : XLALFrameNew() failed with error = %d.\n",fn,xlalErrno);
@@ -453,66 +455,94 @@ int main(int argc, char **argv)
 	      XLALPrintError("Out of memory");
 	      XLAL_ERROR ( XLAL_EFUNC );
 	    }
-	    /*read in parameters from .par file */
-	    /*XLALReadTEMPOParFile( &pulparams, pulin);*/
 
-	    fprintf(stderr,"Your f0 is %f\n",pulparams[h].f0);
+            REAL8Vector *fs = PulsarGetREAL8VectorParam(pulparams[h], "F");
+            fprintf(stderr,"Your f0 is %f\n",fs->data[0]);
 
 	    /*Convert location with proper motion */
-	    if ( pulparams[h].posepoch == 0.0 )
-	      pulparams[h].posepoch = pulparams[h].pepoch; /*set posepoch to pepoch if position epoch not present */
-	    INT4 dtpos = epoch.gpsSeconds - (INT4)pulparams[h].posepoch; /*calculate time since posepoch */
+            INT4 dtpos = 0;
+            if ( PulsarCheckParam(pulparams[h], "POSEPOCH") )
+              dtpos = epoch.gpsSeconds - (INT4)PulsarGetREAL8Param(pulparams[h], "POSEPOCH"); /*calculate time since posepoch */
+            else
+              dtpos = epoch.gpsSeconds - (INT4)PulsarGetREAL8Param(pulparams[h], "PEPOCH");   /*calculate time since pepoch */
 
-	    params.pulsar.position.latitude = pulparams[h].dec + dtpos * pulparams[h].pmdec;
-	    params.pulsar.position.longitude = pulparams[h].ra + dtpos * pulparams[h].pmra / cos(params.pulsar.position.latitude);
+            REAL8 ra = 0., dec = 0.;
+            if ( PulsarCheckParam( pulparams[h], "RAJ" ) ) {
+              ra = PulsarGetREAL8Param( pulparams[h], "RAJ" );
+            }
+            else if ( PulsarCheckParam( pulparams[h], "RA" ) ){
+              ra = PulsarGetREAL8Param( pulparams[h], "RA" );
+            }
+            else{
+              XLALPrintError("No right ascension found");
+              XLAL_ERROR ( XLAL_EFUNC );
+            }
+            if ( PulsarCheckParam( pulparams[h], "DECJ" ) ) {
+              dec = PulsarGetREAL8Param( pulparams[h], "DECJ" );
+            }
+            else if ( PulsarCheckParam( pulparams[h], "DEC" ) ){
+              dec = PulsarGetREAL8Param( pulparams[h], "DEC" );
+            }
+            else{
+              XLALPrintError("No declination found");
+              XLAL_ERROR ( XLAL_EFUNC );
+            }
+
+	    params.pulsar.position.latitude = dec + (REAL8)dtpos * PulsarGetREAL8ParamOrZero(pulparams[h], "PMDEC");
+	    params.pulsar.position.longitude = ra + (REAL8)dtpos * PulsarGetREAL8ParamOrZero(pulparams[h], "PMRA") / cos(params.pulsar.position.latitude);
 	    params.pulsar.position.system = COORDINATESYSTEM_EQUATORIAL;
 
-	    params.pulsar.f0 = 2.*pulparams[h].f0;
-	    params.pulsar.spindown->data[0] = 2.*pulparams[h].f1; /* first frequency derivative */
-	    params.pulsar.spindown->data[1] = 2.*pulparams[h].f2; /* second frequency derivative */
-            params.pulsar.spindown->data[2] = 2.*pulparams[h].f3; /* third frequency derivative */
-	    if (( XLALGPSSetREAL8(&(params.pulsar.refTime),pulparams[h].pepoch) ) == NULL ){
+	    params.pulsar.f0 = 2.*fs->data[0];
+            for ( UINT4 k = 0; k < 3; k++ ){
+              // set frequency derivaties (up to third derivative)
+              if ( fs->length > k ){ params.pulsar.spindown->data[k] = 2.*fs->data[k+1]; }
+              else { params.pulsar.spindown->data[k] = 0.; }
+            }
+	    if (( XLALGPSSetREAL8(&(params.pulsar.refTime),PulsarGetREAL8Param(pulparams[h], "PEPOCH")) ) == NULL ){
 	      XLAL_ERROR ( XLAL_EFUNC );
 	    }
-	    params.pulsar.psi = pulparams[h].psi;
-	    params.pulsar.phi0 = pulparams[h].phi0;
+	    params.pulsar.psi = PulsarGetREAL8ParamOrZero(pulparams[h], "PSI");
+	    params.pulsar.phi0 = PulsarGetREAL8ParamOrZero(pulparams[h], "PHI0");
 	    /*Conversion from h0 and cosi to plus and cross */
-	    params.pulsar.aPlus = 0.5 * pulparams[h].h0 * (1. + pulparams[h].cosiota * pulparams[h].cosiota );
-	    params.pulsar.aCross = pulparams[h].h0 * pulparams[h].cosiota;
+            REAL8 cosiota = PulsarGetREAL8ParamOrZero(pulparams[h], "COSIOTA");
+            REAL8 h0 = PulsarGetREAL8ParamOrZero(pulparams[h], "H0");
+	    params.pulsar.aPlus = 0.5 * h0 * (1. + cosiota * cosiota );
+	    params.pulsar.aCross = h0 * cosiota;
 
 	    /*if binary */
-	    if (pulparams[h].model != NULL) {
+	    if (PulsarCheckParam(pulparams[h], "BINARY")) {
 	      /*fprintf(stderr, "You have a binary! %s", pulin);*/
-	      params.orbit.asini = pulparams[h].x;
-	      params.orbit.period = pulparams[h].Pb*86400;
+	      params.orbit.asini = PulsarGetREAL8ParamOrZero(pulparams[h], "A1");
+	      params.orbit.period = PulsarGetREAL8ParamOrZero(pulparams[h], "PB")*86400;
 
 	      /*Taking into account ELL1 model option */
-	      if (strstr(pulparams[h].model,"ELL1") != NULL) {
+	      if (strstr(PulsarGetStringParam(pulparams[h], "BINARY"),"ELL1") != NULL) {
 		REAL8 w,e,eps1,eps2;
-		eps1 = pulparams[h].eps1;
-		eps2 = pulparams[h].eps2;
+		eps1 = PulsarGetREAL8ParamOrZero(pulparams[h], "EPS1");
+		eps2 = PulsarGetREAL8ParamOrZero(pulparams[h], "EPS2");
 		w = atan2(eps1,eps2);
 		e = sqrt(eps1*eps1+eps2*eps2);
 		params.orbit.argp = w;
 		params.orbit.ecc = e;
 	      }
 	      else {
-		params.orbit.argp = pulparams[h].w0;
-		params.orbit.ecc = pulparams[h].e;
+		params.orbit.argp = PulsarGetREAL8ParamOrZero(pulparams[h], "OM");
+		params.orbit.ecc = PulsarGetREAL8ParamOrZero(pulparams[h], "ECC");
 	      }
-	      if (strstr(pulparams[h].model,"ELL1") != NULL) {
-		REAL8 fe, uasc, Dt;
+	      if (strstr(PulsarGetStringParam(pulparams[h], "BINARY"),"ELL1") != NULL) {
+		REAL8 fe, uasc, Dt, T0val = 0.;
 		fe = sqrt((1.0-params.orbit.ecc)/(1.0+params.orbit.ecc));
 		uasc = 2.0*atan(fe*tan(params.orbit.argp/2.0));
 		Dt = (params.orbit.period/LAL_TWOPI)*(uasc-params.orbit.ecc*sin(uasc));
-		pulparams[h].T0 = pulparams[h].Tasc + Dt;
+		T0val = PulsarGetREAL8ParamOrZero(pulparams[h], "TASC") + Dt;
+                PulsarAddParam(pulparams[h], "T0", &T0val, PULSARTYPE_REAL8_t );
 	      }
 
-	      params.orbit.tp.gpsSeconds = (UINT4)floor(pulparams[h].T0);
-	      params.orbit.tp.gpsNanoSeconds = (UINT4)floor((pulparams[h].T0 - params.orbit.tp.gpsSeconds)*1e9);
-	    } /* if pulparams.model is BINARY */
+	      params.orbit.tp.gpsSeconds = (UINT4)floor(PulsarGetREAL8ParamOrZero(pulparams[h], "T0"));
+	      params.orbit.tp.gpsNanoSeconds = (UINT4)floor((PulsarGetREAL8ParamOrZero(pulparams[h], "T0") - params.orbit.tp.gpsSeconds)*1e9);
+	    } /* if is a BINARY */
 	    else {
-	      XLAL_INIT_MEM(params.orbit); /*if pulparams.model = NULL -- isolated pulsar*/
+	      XLAL_INIT_MEM(params.orbit); /*if not a binary pulsar*/
             }
 	    params.site = site;
 	    params.ephemerides = edat;
@@ -667,7 +697,7 @@ InitUserVars ( UserInput_t *uvar,      /**< [out] UserInput structure to be fill
   XLALRegisterUvarMember( logDir, STRING, 'L', OPTIONAL, "Directory to put .log file");
 
   BOOLEAN should_exit = 0;
-  XLAL_CHECK( XLALUserVarReadAllInput( &should_exit, argc, argv ) == XLAL_SUCCESS, XLAL_EFUNC );
+  XLAL_CHECK( XLALUserVarReadAllInput( &should_exit, argc, argv, lalAppsVCSInfoList ) == XLAL_SUCCESS, XLAL_EFUNC );
   if ( should_exit ) {
     exit(1);
   }
