@@ -111,6 +111,7 @@ extern "C" {
 #define NFREQMAX 4                    /* the max dimensionality of the frequency derivitive grid */
 #define NBINMAX 4                        /* the number of binary parameter dimensions */
 #define NBINS 4                       /* the number of bins to add to each side of the fft for safety */
+#define BINS_FACTOR 0.075             /* the default percentage of bins to add to each side of the fft for safety */
 #define WINGS_FACTOR 2                /* the safety factor in reading extra frequency from SFTs */
 #define MAXNTSERIES 1073741824        /* the max number of samples in a timeseries at one time */
 
@@ -149,7 +150,7 @@ extern "C" {
     REAL8 *x;                         /**< the location in parameter space */
     INT4 *idx;                        /**< the index of each dimension for this template */
     UINT4 ndim;                       /**< the dimension of the parameter space */
-    UINT4 currentidx;                 /**< the current index value of the template */
+    UINT8 currentidx;                 /**< the current index value of the template */
   } Template;
 
   /** Stores the gridding parameters for a hypercubic grid of templates
@@ -158,9 +159,10 @@ extern "C" {
     Grid *grid;                       /**< stores the parameters defining a single dimension */
     UINT4 ndim;                       /**< the number of dimensions */
     UINT4 *prod;                      /**< internal variable used to store the size of sub-dimensions */
-    UINT4 max;                        /**< the maximum (total) number of templates */
+    UINT8 max;                        /**< the maximum (total) number of templates */
     REAL8 mismatch;                   /**< the mismatch */
-    INT4 Nr;
+    REAL8 coverage;                   /**< random template bank coverage */
+    UINT8 Nr;                         /**< number of random templates to generate */
   } GridParameters;
 
    /** Stores the gridding parameters for a hypercubic grid of templates
@@ -211,7 +213,7 @@ extern "C" {
    */
   typedef struct {
     REAL8 tsamp;                      /**< the sampling time of the data */
-    INT4 tsft;                        /**< the length of the SFTs */
+    REAL8 tsft;                       /**< the length of the SFTs */
     LIGOTimeGPS tstart;               /**< the first sft time stamp */
     REAL8 freq;                       /**< the starting frequency */
     REAL8 freqband;                   /**< the band width */
@@ -226,9 +228,9 @@ extern "C" {
     gsl_rng *r;
   } BinaryToSFTparams;
 
-  int XLALReadSFTs(SFTVector**,CHAR *,REAL8,REAL8,INT4,INT4,INT4);
-  int XLALComputeFreqGridParamsVector(GridParametersVector**,REAL8Space*,SFTVector*,REAL8);
-  int XLALComputeFreqGridParams(GridParameters **freqgridparams,REAL8Space *pspace, REAL8 tmid,REAL8 tsft, REAL8 mu);
+  int XLALReadSFTs(SFTVector**,CHAR *,REAL8,REAL8,INT4,INT4,LIGOTimeGPSVector *,REAL8,REAL8);
+  int XLALComputeFreqGridParamsVector(GridParametersVector**,REAL8Space*,SFTVector*,REAL8,INT4*,REAL8);
+  int XLALComputeFreqGridParams(GridParameters **freqgridparams,REAL8Space *pspace, REAL8 tmid,REAL8 tsft, REAL8 mu, INT4 *ndim, REAL8 bins_factor);
   int XLALSFTVectorToCOMPLEX8TimeSeriesArray(COMPLEX8TimeSeriesArray **dstimevec, SFTVector *sftvec);
   int XLALSFTToCOMPLEX8TimeSeries(COMPLEX8TimeSeries **ts, COMPLEX8FrequencySeries *sft,COMPLEX8FFTPlan **plan);
   int XLALCOMPLEX8TimeSeriesToCOMPLEX8FrequencySeries(COMPLEX8FrequencySeries **fs,const COMPLEX8TimeSeries *ts,GridParameters **gridparams);
