@@ -332,21 +332,13 @@ int main( int argc, char **argv )
   {
     PTFSpinTmplt = PTFSpinTmpltHead;
     PTFSpinTmpltHead = PTFSpinTmplt->next;
-    if ( PTFSpinTmplt->event_id )
-    {
-      LALFree( PTFSpinTmplt->event_id );
-    }
-    LALFree( PTFSpinTmplt );
+    XLALFreeSnglInspiral( &PTFSpinTmplt );
   }
   while ( PTFNoSpinTmpltHead )
   {
     PTFNoSpinTmplt = PTFNoSpinTmpltHead;
     PTFNoSpinTmpltHead = PTFNoSpinTmplt->next;
-    if ( PTFNoSpinTmplt->event_id )
-    {
-      LALFree( PTFNoSpinTmplt->event_id );
-    }
-    LALFree( PTFNoSpinTmplt );
+    XLALFreeSnglInspiral( &PTFNoSpinTmplt );
   }
 
   LALCheckMemoryLeaks();
