@@ -512,8 +512,9 @@ static REAL4FrequencySeries *ring_get_invspec(
       invspec = XLALCreateREAL4FrequencySeries("TEMP",&(channel->epoch),0,
           1.0/params->segmentDuration,&lalDimensionlessUnit,
           segmentLength/2 + 1);
-      snprintf( invspec->name, sizeof( invspec->name),
-          "%s_SPEC", channel->name);
+      if((int)sizeof(invspec->name) <= snprintf( invspec->name, sizeof( invspec->name),
+          "%s_SPEC", channel->name))
+			  XLAL_ERROR_NULL(XLAL_FAILURE,"snprintf truncation!");
       for ( k = 0; k < spectrum->data->length; ++k )
       {
         invspec->data->data[k] = (REAL4)(spectrum->data->data[k]*params->dynRangeFac*params->dynRangeFac);
